/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleApigeeSecurityMonitoringConditionConfig extends cdktf.TerraformMetaArguments {
    /**
    * Resource ID of the security monitoring condition.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_apigee_security_monitoring_condition#condition_id GoogleApigeeSecurityMonitoringCondition#condition_id}
    */
    readonly conditionId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_apigee_security_monitoring_condition#id GoogleApigeeSecurityMonitoringCondition#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The Apigee Organization associated with the Apigee Security Monitoring Condition,
    * in the format 'organizations/{{org_name}}'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_apigee_security_monitoring_condition#org_id GoogleApigeeSecurityMonitoringCondition#org_id}
    */
    readonly orgId: string;
    /**
    * ID of security profile of the security monitoring condition.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_apigee_security_monitoring_condition#profile GoogleApigeeSecurityMonitoringCondition#profile}
    */
    readonly profile: string;
    /**
    * ID of security profile of the security monitoring condition.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_apigee_security_monitoring_condition#scope GoogleApigeeSecurityMonitoringCondition#scope}
    */
    readonly scope: string;
    /**
    * include_all_resources block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_apigee_security_monitoring_condition#include_all_resources GoogleApigeeSecurityMonitoringCondition#include_all_resources}
    */
    readonly includeAllResources?: GoogleApigeeSecurityMonitoringConditionIncludeAllResources;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_apigee_security_monitoring_condition#timeouts GoogleApigeeSecurityMonitoringCondition#timeouts}
    */
    readonly timeouts?: GoogleApigeeSecurityMonitoringConditionTimeouts;
}
export interface GoogleApigeeSecurityMonitoringConditionIncludeAllResources {
}
export declare function googleApigeeSecurityMonitoringConditionIncludeAllResourcesToTerraform(struct?: GoogleApigeeSecurityMonitoringConditionIncludeAllResourcesOutputReference | GoogleApigeeSecurityMonitoringConditionIncludeAllResources): any;
export declare function googleApigeeSecurityMonitoringConditionIncludeAllResourcesToHclTerraform(struct?: GoogleApigeeSecurityMonitoringConditionIncludeAllResourcesOutputReference | GoogleApigeeSecurityMonitoringConditionIncludeAllResources): any;
export declare class GoogleApigeeSecurityMonitoringConditionIncludeAllResourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleApigeeSecurityMonitoringConditionIncludeAllResources | undefined;
    set internalValue(value: GoogleApigeeSecurityMonitoringConditionIncludeAllResources | undefined);
}
export interface GoogleApigeeSecurityMonitoringConditionTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_apigee_security_monitoring_condition#create GoogleApigeeSecurityMonitoringCondition#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_apigee_security_monitoring_condition#delete GoogleApigeeSecurityMonitoringCondition#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_apigee_security_monitoring_condition#update GoogleApigeeSecurityMonitoringCondition#update}
    */
    readonly update?: string;
}
export declare function googleApigeeSecurityMonitoringConditionTimeoutsToTerraform(struct?: GoogleApigeeSecurityMonitoringConditionTimeouts | cdktf.IResolvable): any;
export declare function googleApigeeSecurityMonitoringConditionTimeoutsToHclTerraform(struct?: GoogleApigeeSecurityMonitoringConditionTimeouts | cdktf.IResolvable): any;
export declare class GoogleApigeeSecurityMonitoringConditionTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleApigeeSecurityMonitoringConditionTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleApigeeSecurityMonitoringConditionTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_apigee_security_monitoring_condition google_apigee_security_monitoring_condition}
*/
export declare class GoogleApigeeSecurityMonitoringCondition extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_apigee_security_monitoring_condition";
    /**
    * Generates CDKTF code for importing a GoogleApigeeSecurityMonitoringCondition resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleApigeeSecurityMonitoringCondition to import
    * @param importFromId The id of the existing GoogleApigeeSecurityMonitoringCondition that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_apigee_security_monitoring_condition#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleApigeeSecurityMonitoringCondition to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_apigee_security_monitoring_condition google_apigee_security_monitoring_condition} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleApigeeSecurityMonitoringConditionConfig
    */
    constructor(scope: Construct, id: string, config: GoogleApigeeSecurityMonitoringConditionConfig);
    private _conditionId?;
    get conditionId(): string;
    set conditionId(value: string);
    get conditionIdInput(): string | undefined;
    get createTime(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _orgId?;
    get orgId(): string;
    set orgId(value: string);
    get orgIdInput(): string | undefined;
    private _profile?;
    get profile(): string;
    set profile(value: string);
    get profileInput(): string | undefined;
    private _scope?;
    get scope(): string;
    set scope(value: string);
    get scopeInput(): string | undefined;
    get totalDeployedResources(): number;
    get totalMonitoredResources(): number;
    get updateTime(): string;
    private _includeAllResources;
    get includeAllResources(): GoogleApigeeSecurityMonitoringConditionIncludeAllResourcesOutputReference;
    putIncludeAllResources(value: GoogleApigeeSecurityMonitoringConditionIncludeAllResources): void;
    resetIncludeAllResources(): void;
    get includeAllResourcesInput(): GoogleApigeeSecurityMonitoringConditionIncludeAllResources | undefined;
    private _timeouts;
    get timeouts(): GoogleApigeeSecurityMonitoringConditionTimeoutsOutputReference;
    putTimeouts(value: GoogleApigeeSecurityMonitoringConditionTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleApigeeSecurityMonitoringConditionTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
