/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleCloudRunV2WorkerPoolConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unstructured key value map that may be set by external tools to store and arbitrary metadata. They are not queryable and should be preserved when modifying objects.
    *
    * Cloud Run API v2 does not support annotations with 'run.googleapis.com', 'cloud.googleapis.com', 'serving.knative.dev', or 'autoscaling.knative.dev' namespaces, and they will be rejected in new resources.
    * All system annotations in v1 now have a corresponding field in v2 WorkerPool.
    *
    * This field follows Kubernetes annotations' namespacing, limits, and rules.
    *
    * **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
    * Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#annotations GoogleCloudRunV2WorkerPool#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * Arbitrary identifier for the API client.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#client GoogleCloudRunV2WorkerPool#client}
    */
    readonly client?: string;
    /**
    * Arbitrary version identifier for the API client.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#client_version GoogleCloudRunV2WorkerPool#client_version}
    */
    readonly clientVersion?: string;
    /**
    * One or more custom audiences that you want this worker pool to support. Specify each custom audience as the full URL in a string. The custom audiences are encoded in the token and used to authenticate requests.
    * For more information, see https://cloud.google.com/run/docs/configuring/custom-audiences.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#custom_audiences GoogleCloudRunV2WorkerPool#custom_audiences}
    */
    readonly customAudiences?: string[];
    /**
    * Whether Terraform will be prevented from destroying the service. Defaults to true.
    * When a'terraform destroy' or 'terraform apply' would delete the service,
    * the command will fail if this field is not set to false in Terraform state.
    * When the field is set to true or unset in Terraform state, a 'terraform apply'
    * or 'terraform destroy' that would delete the WorkerPool will fail.
    * When the field is set to false, deleting the WorkerPool is allowed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#deletion_protection GoogleCloudRunV2WorkerPool#deletion_protection}
    */
    readonly deletionProtection?: boolean | cdktf.IResolvable;
    /**
    * User-provided description of the WorkerPool. This field currently has a 512-character limit.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#description GoogleCloudRunV2WorkerPool#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#id GoogleCloudRunV2WorkerPool#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Unstructured key value map that can be used to organize and categorize objects. User-provided labels are shared with Google's billing system, so they can be used to filter, or break down billing charges by team, component,
    * environment, state, etc. For more information, visit https://cloud.google.com/resource-manager/docs/creating-managing-labels or https://cloud.google.com/run/docs/configuring/labels.
    *
    * Cloud Run API v2 does not support labels with  'run.googleapis.com', 'cloud.googleapis.com', 'serving.knative.dev', or 'autoscaling.knative.dev' namespaces, and they will be rejected.
    * All system labels in v1 now have a corresponding field in v2 WorkerPool.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#labels GoogleCloudRunV2WorkerPool#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The launch stage as defined by [Google Cloud Platform Launch Stages](https://cloud.google.com/products#product-launch-stages). Cloud Run supports ALPHA, BETA, and GA.
    * If no value is specified, GA is assumed. Set the launch stage to a preview stage on input to allow use of preview features in that stage. On read (or output), describes whether the resource uses preview features.
    *
    * For example, if ALPHA is provided as input, but only BETA and GA-level features are used, this field will be BETA on output. Possible values: ["UNIMPLEMENTED", "PRELAUNCH", "EARLY_ACCESS", "ALPHA", "BETA", "GA", "DEPRECATED"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#launch_stage GoogleCloudRunV2WorkerPool#launch_stage}
    */
    readonly launchStage?: string;
    /**
    * The location of the cloud run worker pool
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#location GoogleCloudRunV2WorkerPool#location}
    */
    readonly location: string;
    /**
    * Name of the WorkerPool.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#name GoogleCloudRunV2WorkerPool#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#project GoogleCloudRunV2WorkerPool#project}
    */
    readonly project?: string;
    /**
    * binary_authorization block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#binary_authorization GoogleCloudRunV2WorkerPool#binary_authorization}
    */
    readonly binaryAuthorization?: GoogleCloudRunV2WorkerPoolBinaryAuthorization;
    /**
    * instance_splits block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#instance_splits GoogleCloudRunV2WorkerPool#instance_splits}
    */
    readonly instanceSplits?: GoogleCloudRunV2WorkerPoolInstanceSplits[] | cdktf.IResolvable;
    /**
    * scaling block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#scaling GoogleCloudRunV2WorkerPool#scaling}
    */
    readonly scaling?: GoogleCloudRunV2WorkerPoolScaling;
    /**
    * template block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#template GoogleCloudRunV2WorkerPool#template}
    */
    readonly template: GoogleCloudRunV2WorkerPoolTemplate;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#timeouts GoogleCloudRunV2WorkerPool#timeouts}
    */
    readonly timeouts?: GoogleCloudRunV2WorkerPoolTimeouts;
}
export interface GoogleCloudRunV2WorkerPoolConditions {
}
export declare function googleCloudRunV2WorkerPoolConditionsToTerraform(struct?: GoogleCloudRunV2WorkerPoolConditions): any;
export declare function googleCloudRunV2WorkerPoolConditionsToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolConditions): any;
export declare class GoogleCloudRunV2WorkerPoolConditionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleCloudRunV2WorkerPoolConditions | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolConditions | undefined);
    get executionReason(): string;
    get lastTransitionTime(): string;
    get message(): string;
    get reason(): string;
    get revisionReason(): string;
    get severity(): string;
    get state(): string;
    get type(): string;
}
export declare class GoogleCloudRunV2WorkerPoolConditionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleCloudRunV2WorkerPoolConditionsOutputReference;
}
export interface GoogleCloudRunV2WorkerPoolInstanceSplitStatuses {
}
export declare function googleCloudRunV2WorkerPoolInstanceSplitStatusesToTerraform(struct?: GoogleCloudRunV2WorkerPoolInstanceSplitStatuses): any;
export declare function googleCloudRunV2WorkerPoolInstanceSplitStatusesToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolInstanceSplitStatuses): any;
export declare class GoogleCloudRunV2WorkerPoolInstanceSplitStatusesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleCloudRunV2WorkerPoolInstanceSplitStatuses | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolInstanceSplitStatuses | undefined);
    get percent(): number;
    get revision(): string;
    get type(): string;
}
export declare class GoogleCloudRunV2WorkerPoolInstanceSplitStatusesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleCloudRunV2WorkerPoolInstanceSplitStatusesOutputReference;
}
export interface GoogleCloudRunV2WorkerPoolTerminalCondition {
}
export declare function googleCloudRunV2WorkerPoolTerminalConditionToTerraform(struct?: GoogleCloudRunV2WorkerPoolTerminalCondition): any;
export declare function googleCloudRunV2WorkerPoolTerminalConditionToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolTerminalCondition): any;
export declare class GoogleCloudRunV2WorkerPoolTerminalConditionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleCloudRunV2WorkerPoolTerminalCondition | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolTerminalCondition | undefined);
    get executionReason(): string;
    get lastTransitionTime(): string;
    get message(): string;
    get reason(): string;
    get revisionReason(): string;
    get severity(): string;
    get state(): string;
    get type(): string;
}
export declare class GoogleCloudRunV2WorkerPoolTerminalConditionList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleCloudRunV2WorkerPoolTerminalConditionOutputReference;
}
export interface GoogleCloudRunV2WorkerPoolBinaryAuthorization {
    /**
    * If present, indicates to use Breakglass using this justification. If useDefault is False, then it must be empty. For more information on breakglass, see https://cloud.google.com/binary-authorization/docs/using-breakglass
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#breakglass_justification GoogleCloudRunV2WorkerPool#breakglass_justification}
    */
    readonly breakglassJustification?: string;
    /**
    * The path to a binary authorization policy. Format: projects/{project}/platforms/cloudRun/{policy-name}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#policy GoogleCloudRunV2WorkerPool#policy}
    */
    readonly policy?: string;
    /**
    * If True, indicates to use the default project's binary authorization policy. If False, binary authorization will be disabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#use_default GoogleCloudRunV2WorkerPool#use_default}
    */
    readonly useDefault?: boolean | cdktf.IResolvable;
}
export declare function googleCloudRunV2WorkerPoolBinaryAuthorizationToTerraform(struct?: GoogleCloudRunV2WorkerPoolBinaryAuthorizationOutputReference | GoogleCloudRunV2WorkerPoolBinaryAuthorization): any;
export declare function googleCloudRunV2WorkerPoolBinaryAuthorizationToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolBinaryAuthorizationOutputReference | GoogleCloudRunV2WorkerPoolBinaryAuthorization): any;
export declare class GoogleCloudRunV2WorkerPoolBinaryAuthorizationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudRunV2WorkerPoolBinaryAuthorization | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolBinaryAuthorization | undefined);
    private _breakglassJustification?;
    get breakglassJustification(): string;
    set breakglassJustification(value: string);
    resetBreakglassJustification(): void;
    get breakglassJustificationInput(): string | undefined;
    private _policy?;
    get policy(): string;
    set policy(value: string);
    resetPolicy(): void;
    get policyInput(): string | undefined;
    private _useDefault?;
    get useDefault(): boolean | cdktf.IResolvable;
    set useDefault(value: boolean | cdktf.IResolvable);
    resetUseDefault(): void;
    get useDefaultInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleCloudRunV2WorkerPoolInstanceSplits {
    /**
    * Specifies percent of the instance split to this Revision. This defaults to zero if unspecified.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#percent GoogleCloudRunV2WorkerPool#percent}
    */
    readonly percent?: number;
    /**
    * Revision to which to assign this portion of instances, if split allocation is by revision.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#revision GoogleCloudRunV2WorkerPool#revision}
    */
    readonly revision?: string;
    /**
    * The allocation type for this instance split. Possible values: ["INSTANCE_SPLIT_ALLOCATION_TYPE_LATEST", "INSTANCE_SPLIT_ALLOCATION_TYPE_REVISION"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#type GoogleCloudRunV2WorkerPool#type}
    */
    readonly type?: string;
}
export declare function googleCloudRunV2WorkerPoolInstanceSplitsToTerraform(struct?: GoogleCloudRunV2WorkerPoolInstanceSplits | cdktf.IResolvable): any;
export declare function googleCloudRunV2WorkerPoolInstanceSplitsToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolInstanceSplits | cdktf.IResolvable): any;
export declare class GoogleCloudRunV2WorkerPoolInstanceSplitsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleCloudRunV2WorkerPoolInstanceSplits | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolInstanceSplits | cdktf.IResolvable | undefined);
    private _percent?;
    get percent(): number;
    set percent(value: number);
    resetPercent(): void;
    get percentInput(): number | undefined;
    private _revision?;
    get revision(): string;
    set revision(value: string);
    resetRevision(): void;
    get revisionInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
}
export declare class GoogleCloudRunV2WorkerPoolInstanceSplitsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleCloudRunV2WorkerPoolInstanceSplits[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleCloudRunV2WorkerPoolInstanceSplitsOutputReference;
}
export interface GoogleCloudRunV2WorkerPoolScaling {
    /**
    * The total number of instances in manual scaling mode.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#manual_instance_count GoogleCloudRunV2WorkerPool#manual_instance_count}
    */
    readonly manualInstanceCount?: number;
    /**
    * The maximum count of instances distributed among revisions based on the specified instance split percentages.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#max_instance_count GoogleCloudRunV2WorkerPool#max_instance_count}
    */
    readonly maxInstanceCount?: number;
    /**
    * The minimum count of instances distributed among revisions based on the specified instance split percentages.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#min_instance_count GoogleCloudRunV2WorkerPool#min_instance_count}
    */
    readonly minInstanceCount?: number;
    /**
    * The scaling mode for the worker pool. It defaults to MANUAL. Possible values: ["AUTOMATIC", "MANUAL"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#scaling_mode GoogleCloudRunV2WorkerPool#scaling_mode}
    */
    readonly scalingMode?: string;
}
export declare function googleCloudRunV2WorkerPoolScalingToTerraform(struct?: GoogleCloudRunV2WorkerPoolScalingOutputReference | GoogleCloudRunV2WorkerPoolScaling): any;
export declare function googleCloudRunV2WorkerPoolScalingToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolScalingOutputReference | GoogleCloudRunV2WorkerPoolScaling): any;
export declare class GoogleCloudRunV2WorkerPoolScalingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudRunV2WorkerPoolScaling | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolScaling | undefined);
    private _manualInstanceCount?;
    get manualInstanceCount(): number;
    set manualInstanceCount(value: number);
    resetManualInstanceCount(): void;
    get manualInstanceCountInput(): number | undefined;
    private _maxInstanceCount?;
    get maxInstanceCount(): number;
    set maxInstanceCount(value: number);
    resetMaxInstanceCount(): void;
    get maxInstanceCountInput(): number | undefined;
    private _minInstanceCount?;
    get minInstanceCount(): number;
    set minInstanceCount(value: number);
    resetMinInstanceCount(): void;
    get minInstanceCountInput(): number | undefined;
    private _scalingMode?;
    get scalingMode(): string;
    set scalingMode(value: string);
    resetScalingMode(): void;
    get scalingModeInput(): string | undefined;
}
export interface GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceSecretKeyRef {
    /**
    * The name of the secret in Cloud Secret Manager. Format: {secretName} if the secret is in the same project. projects/{project}/secrets/{secretName} if the secret is in a different project.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#secret GoogleCloudRunV2WorkerPool#secret}
    */
    readonly secret: string;
    /**
    * The Cloud Secret Manager secret version. Can be 'latest' for the latest value or an integer for a specific version.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#version GoogleCloudRunV2WorkerPool#version}
    */
    readonly version?: string;
}
export declare function googleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceSecretKeyRefToTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceSecretKeyRefOutputReference | GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceSecretKeyRef): any;
export declare function googleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceSecretKeyRefToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceSecretKeyRefOutputReference | GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceSecretKeyRef): any;
export declare class GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceSecretKeyRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceSecretKeyRef | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceSecretKeyRef | undefined);
    private _secret?;
    get secret(): string;
    set secret(value: string);
    get secretInput(): string | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    resetVersion(): void;
    get versionInput(): string | undefined;
}
export interface GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSource {
    /**
    * secret_key_ref block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#secret_key_ref GoogleCloudRunV2WorkerPool#secret_key_ref}
    */
    readonly secretKeyRef?: GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceSecretKeyRef;
}
export declare function googleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceToTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceOutputReference | GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSource): any;
export declare function googleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceOutputReference | GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSource): any;
export declare class GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSource | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSource | undefined);
    private _secretKeyRef;
    get secretKeyRef(): GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceSecretKeyRefOutputReference;
    putSecretKeyRef(value: GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceSecretKeyRef): void;
    resetSecretKeyRef(): void;
    get secretKeyRefInput(): GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceSecretKeyRef | undefined;
}
export interface GoogleCloudRunV2WorkerPoolTemplateContainersEnv {
    /**
    * Name of the environment variable. Must be a C_IDENTIFIER, and may not exceed 32768 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#name GoogleCloudRunV2WorkerPool#name}
    */
    readonly name: string;
    /**
    * Literal value of the environment variable. Defaults to "" and the maximum allowed length is 32768 characters. Variable references are not supported in Cloud Run.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#value GoogleCloudRunV2WorkerPool#value}
    */
    readonly value?: string;
    /**
    * value_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#value_source GoogleCloudRunV2WorkerPool#value_source}
    */
    readonly valueSource?: GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSource;
}
export declare function googleCloudRunV2WorkerPoolTemplateContainersEnvToTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateContainersEnv | cdktf.IResolvable): any;
export declare function googleCloudRunV2WorkerPoolTemplateContainersEnvToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateContainersEnv | cdktf.IResolvable): any;
export declare class GoogleCloudRunV2WorkerPoolTemplateContainersEnvOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleCloudRunV2WorkerPoolTemplateContainersEnv | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolTemplateContainersEnv | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
    private _valueSource;
    get valueSource(): GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSourceOutputReference;
    putValueSource(value: GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSource): void;
    resetValueSource(): void;
    get valueSourceInput(): GoogleCloudRunV2WorkerPoolTemplateContainersEnvValueSource | undefined;
}
export declare class GoogleCloudRunV2WorkerPoolTemplateContainersEnvList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleCloudRunV2WorkerPoolTemplateContainersEnv[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleCloudRunV2WorkerPoolTemplateContainersEnvOutputReference;
}
export interface GoogleCloudRunV2WorkerPoolTemplateContainersResources {
    /**
    * Only memory, CPU, and nvidia.com/gpu are supported. Use key 'cpu' for CPU limit, 'memory' for memory limit, 'nvidia.com/gpu' for gpu limit. Note: The only supported values for CPU are '1', '2', '4', and '8'. Setting 4 CPU requires at least 2Gi of memory. The values of the map is string form of the 'quantity' k8s type: https://github.com/kubernetes/kubernetes/blob/master/staging/src/k8s.io/apimachinery/pkg/api/resource/quantity.go
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#limits GoogleCloudRunV2WorkerPool#limits}
    */
    readonly limits?: {
        [key: string]: string;
    };
}
export declare function googleCloudRunV2WorkerPoolTemplateContainersResourcesToTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateContainersResourcesOutputReference | GoogleCloudRunV2WorkerPoolTemplateContainersResources): any;
export declare function googleCloudRunV2WorkerPoolTemplateContainersResourcesToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateContainersResourcesOutputReference | GoogleCloudRunV2WorkerPoolTemplateContainersResources): any;
export declare class GoogleCloudRunV2WorkerPoolTemplateContainersResourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudRunV2WorkerPoolTemplateContainersResources | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolTemplateContainersResources | undefined);
    private _limits?;
    get limits(): {
        [key: string]: string;
    };
    set limits(value: {
        [key: string]: string;
    });
    resetLimits(): void;
    get limitsInput(): {
        [key: string]: string;
    } | undefined;
}
export interface GoogleCloudRunV2WorkerPoolTemplateContainersVolumeMounts {
    /**
    * Path within the container at which the volume should be mounted. Must not contain ':'. For Cloud SQL volumes, it can be left empty, or must otherwise be /cloudsql. All instances defined in the Volume will be available as /cloudsql/[instance]. For more information on Cloud SQL volumes, visit https://cloud.google.com/sql/docs/mysql/connect-run
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#mount_path GoogleCloudRunV2WorkerPool#mount_path}
    */
    readonly mountPath: string;
    /**
    * This must match the Name of a Volume.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#name GoogleCloudRunV2WorkerPool#name}
    */
    readonly name: string;
}
export declare function googleCloudRunV2WorkerPoolTemplateContainersVolumeMountsToTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateContainersVolumeMounts | cdktf.IResolvable): any;
export declare function googleCloudRunV2WorkerPoolTemplateContainersVolumeMountsToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateContainersVolumeMounts | cdktf.IResolvable): any;
export declare class GoogleCloudRunV2WorkerPoolTemplateContainersVolumeMountsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleCloudRunV2WorkerPoolTemplateContainersVolumeMounts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolTemplateContainersVolumeMounts | cdktf.IResolvable | undefined);
    private _mountPath?;
    get mountPath(): string;
    set mountPath(value: string);
    get mountPathInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
}
export declare class GoogleCloudRunV2WorkerPoolTemplateContainersVolumeMountsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleCloudRunV2WorkerPoolTemplateContainersVolumeMounts[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleCloudRunV2WorkerPoolTemplateContainersVolumeMountsOutputReference;
}
export interface GoogleCloudRunV2WorkerPoolTemplateContainers {
    /**
    * Arguments to the entrypoint. The docker image's CMD is used if this is not provided. Variable references are not supported in Cloud Run.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#args GoogleCloudRunV2WorkerPool#args}
    */
    readonly args?: string[];
    /**
    * Entrypoint array. Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#command GoogleCloudRunV2WorkerPool#command}
    */
    readonly command?: string[];
    /**
    * Containers which should be started before this container. If specified the container will wait to start until all containers with the listed names are healthy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#depends_on GoogleCloudRunV2WorkerPool#depends_on}
    */
    readonly dependsOn?: string[];
    /**
    * URL of the Container image in Google Container Registry or Google Artifact Registry. More info: https://kubernetes.io/docs/concepts/containers/images
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#image GoogleCloudRunV2WorkerPool#image}
    */
    readonly image: string;
    /**
    * Name of the container specified as a DNS_LABEL.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#name GoogleCloudRunV2WorkerPool#name}
    */
    readonly name?: string;
    /**
    * Container's working directory. If not specified, the container runtime's default will be used, which might be configured in the container image.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#working_dir GoogleCloudRunV2WorkerPool#working_dir}
    */
    readonly workingDir?: string;
    /**
    * env block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#env GoogleCloudRunV2WorkerPool#env}
    */
    readonly env?: GoogleCloudRunV2WorkerPoolTemplateContainersEnv[] | cdktf.IResolvable;
    /**
    * resources block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#resources GoogleCloudRunV2WorkerPool#resources}
    */
    readonly resources?: GoogleCloudRunV2WorkerPoolTemplateContainersResources;
    /**
    * volume_mounts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#volume_mounts GoogleCloudRunV2WorkerPool#volume_mounts}
    */
    readonly volumeMounts?: GoogleCloudRunV2WorkerPoolTemplateContainersVolumeMounts[] | cdktf.IResolvable;
}
export declare function googleCloudRunV2WorkerPoolTemplateContainersToTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateContainers | cdktf.IResolvable): any;
export declare function googleCloudRunV2WorkerPoolTemplateContainersToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateContainers | cdktf.IResolvable): any;
export declare class GoogleCloudRunV2WorkerPoolTemplateContainersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleCloudRunV2WorkerPoolTemplateContainers | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolTemplateContainers | cdktf.IResolvable | undefined);
    private _args?;
    get args(): string[];
    set args(value: string[]);
    resetArgs(): void;
    get argsInput(): string[] | undefined;
    private _command?;
    get command(): string[];
    set command(value: string[]);
    resetCommand(): void;
    get commandInput(): string[] | undefined;
    private _dependsOn?;
    get dependsOn(): string[];
    set dependsOn(value: string[]);
    resetDependsOn(): void;
    get dependsOnInput(): string[] | undefined;
    private _image?;
    get image(): string;
    set image(value: string);
    get imageInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _workingDir?;
    get workingDir(): string;
    set workingDir(value: string);
    resetWorkingDir(): void;
    get workingDirInput(): string | undefined;
    private _env;
    get env(): GoogleCloudRunV2WorkerPoolTemplateContainersEnvList;
    putEnv(value: GoogleCloudRunV2WorkerPoolTemplateContainersEnv[] | cdktf.IResolvable): void;
    resetEnv(): void;
    get envInput(): cdktf.IResolvable | GoogleCloudRunV2WorkerPoolTemplateContainersEnv[] | undefined;
    private _resources;
    get resources(): GoogleCloudRunV2WorkerPoolTemplateContainersResourcesOutputReference;
    putResources(value: GoogleCloudRunV2WorkerPoolTemplateContainersResources): void;
    resetResources(): void;
    get resourcesInput(): GoogleCloudRunV2WorkerPoolTemplateContainersResources | undefined;
    private _volumeMounts;
    get volumeMounts(): GoogleCloudRunV2WorkerPoolTemplateContainersVolumeMountsList;
    putVolumeMounts(value: GoogleCloudRunV2WorkerPoolTemplateContainersVolumeMounts[] | cdktf.IResolvable): void;
    resetVolumeMounts(): void;
    get volumeMountsInput(): cdktf.IResolvable | GoogleCloudRunV2WorkerPoolTemplateContainersVolumeMounts[] | undefined;
}
export declare class GoogleCloudRunV2WorkerPoolTemplateContainersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleCloudRunV2WorkerPoolTemplateContainers[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleCloudRunV2WorkerPoolTemplateContainersOutputReference;
}
export interface GoogleCloudRunV2WorkerPoolTemplateNodeSelector {
    /**
    * The GPU to attach to an instance. See https://cloud.google.com/run/docs/configuring/services/gpu for configuring GPU.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#accelerator GoogleCloudRunV2WorkerPool#accelerator}
    */
    readonly accelerator: string;
}
export declare function googleCloudRunV2WorkerPoolTemplateNodeSelectorToTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateNodeSelectorOutputReference | GoogleCloudRunV2WorkerPoolTemplateNodeSelector): any;
export declare function googleCloudRunV2WorkerPoolTemplateNodeSelectorToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateNodeSelectorOutputReference | GoogleCloudRunV2WorkerPoolTemplateNodeSelector): any;
export declare class GoogleCloudRunV2WorkerPoolTemplateNodeSelectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudRunV2WorkerPoolTemplateNodeSelector | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolTemplateNodeSelector | undefined);
    private _accelerator?;
    get accelerator(): string;
    set accelerator(value: string);
    get acceleratorInput(): string | undefined;
}
export interface GoogleCloudRunV2WorkerPoolTemplateVolumesCloudSqlInstance {
    /**
    * The Cloud SQL instance connection names, as can be found in https://console.cloud.google.com/sql/instances. Visit https://cloud.google.com/sql/docs/mysql/connect-run for more information on how to connect Cloud SQL and Cloud Run. Format: {project}:{location}:{instance}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#instances GoogleCloudRunV2WorkerPool#instances}
    */
    readonly instances?: string[];
}
export declare function googleCloudRunV2WorkerPoolTemplateVolumesCloudSqlInstanceToTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateVolumesCloudSqlInstanceOutputReference | GoogleCloudRunV2WorkerPoolTemplateVolumesCloudSqlInstance): any;
export declare function googleCloudRunV2WorkerPoolTemplateVolumesCloudSqlInstanceToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateVolumesCloudSqlInstanceOutputReference | GoogleCloudRunV2WorkerPoolTemplateVolumesCloudSqlInstance): any;
export declare class GoogleCloudRunV2WorkerPoolTemplateVolumesCloudSqlInstanceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudRunV2WorkerPoolTemplateVolumesCloudSqlInstance | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolTemplateVolumesCloudSqlInstance | undefined);
    private _instances?;
    get instances(): string[];
    set instances(value: string[]);
    resetInstances(): void;
    get instancesInput(): string[] | undefined;
}
export interface GoogleCloudRunV2WorkerPoolTemplateVolumesEmptyDir {
    /**
    * The different types of medium supported for EmptyDir. Default value: "MEMORY" Possible values: ["MEMORY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#medium GoogleCloudRunV2WorkerPool#medium}
    */
    readonly medium?: string;
    /**
    * Limit on the storage usable by this EmptyDir volume. The size limit is also applicable for memory medium. The maximum usage on memory medium EmptyDir would be the minimum value between the SizeLimit specified here and the sum of memory limits of all containers in a pod. This field's values are of the 'Quantity' k8s type: https://kubernetes.io/docs/reference/kubernetes-api/common-definitions/quantity/. The default is nil which means that the limit is undefined. More info: https://kubernetes.io/docs/concepts/storage/volumes/#emptydir.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#size_limit GoogleCloudRunV2WorkerPool#size_limit}
    */
    readonly sizeLimit?: string;
}
export declare function googleCloudRunV2WorkerPoolTemplateVolumesEmptyDirToTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateVolumesEmptyDirOutputReference | GoogleCloudRunV2WorkerPoolTemplateVolumesEmptyDir): any;
export declare function googleCloudRunV2WorkerPoolTemplateVolumesEmptyDirToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateVolumesEmptyDirOutputReference | GoogleCloudRunV2WorkerPoolTemplateVolumesEmptyDir): any;
export declare class GoogleCloudRunV2WorkerPoolTemplateVolumesEmptyDirOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudRunV2WorkerPoolTemplateVolumesEmptyDir | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolTemplateVolumesEmptyDir | undefined);
    private _medium?;
    get medium(): string;
    set medium(value: string);
    resetMedium(): void;
    get mediumInput(): string | undefined;
    private _sizeLimit?;
    get sizeLimit(): string;
    set sizeLimit(value: string);
    resetSizeLimit(): void;
    get sizeLimitInput(): string | undefined;
}
export interface GoogleCloudRunV2WorkerPoolTemplateVolumesGcs {
    /**
    * GCS Bucket name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#bucket GoogleCloudRunV2WorkerPool#bucket}
    */
    readonly bucket: string;
    /**
    * A list of flags to pass to the gcsfuse command for configuring this volume.
    * Flags should be passed without leading dashes.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#mount_options GoogleCloudRunV2WorkerPool#mount_options}
    */
    readonly mountOptions?: string[];
    /**
    * If true, mount the GCS bucket as read-only
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#read_only GoogleCloudRunV2WorkerPool#read_only}
    */
    readonly readOnly?: boolean | cdktf.IResolvable;
}
export declare function googleCloudRunV2WorkerPoolTemplateVolumesGcsToTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateVolumesGcsOutputReference | GoogleCloudRunV2WorkerPoolTemplateVolumesGcs): any;
export declare function googleCloudRunV2WorkerPoolTemplateVolumesGcsToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateVolumesGcsOutputReference | GoogleCloudRunV2WorkerPoolTemplateVolumesGcs): any;
export declare class GoogleCloudRunV2WorkerPoolTemplateVolumesGcsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudRunV2WorkerPoolTemplateVolumesGcs | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolTemplateVolumesGcs | undefined);
    private _bucket?;
    get bucket(): string;
    set bucket(value: string);
    get bucketInput(): string | undefined;
    private _mountOptions?;
    get mountOptions(): string[];
    set mountOptions(value: string[]);
    resetMountOptions(): void;
    get mountOptionsInput(): string[] | undefined;
    private _readOnly?;
    get readOnly(): boolean | cdktf.IResolvable;
    set readOnly(value: boolean | cdktf.IResolvable);
    resetReadOnly(): void;
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleCloudRunV2WorkerPoolTemplateVolumesNfs {
    /**
    * Path that is exported by the NFS server.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#path GoogleCloudRunV2WorkerPool#path}
    */
    readonly path: string;
    /**
    * If true, mount the NFS volume as read only
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#read_only GoogleCloudRunV2WorkerPool#read_only}
    */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
    * Hostname or IP address of the NFS server
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#server GoogleCloudRunV2WorkerPool#server}
    */
    readonly server: string;
}
export declare function googleCloudRunV2WorkerPoolTemplateVolumesNfsToTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateVolumesNfsOutputReference | GoogleCloudRunV2WorkerPoolTemplateVolumesNfs): any;
export declare function googleCloudRunV2WorkerPoolTemplateVolumesNfsToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateVolumesNfsOutputReference | GoogleCloudRunV2WorkerPoolTemplateVolumesNfs): any;
export declare class GoogleCloudRunV2WorkerPoolTemplateVolumesNfsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudRunV2WorkerPoolTemplateVolumesNfs | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolTemplateVolumesNfs | undefined);
    private _path?;
    get path(): string;
    set path(value: string);
    get pathInput(): string | undefined;
    private _readOnly?;
    get readOnly(): boolean | cdktf.IResolvable;
    set readOnly(value: boolean | cdktf.IResolvable);
    resetReadOnly(): void;
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _server?;
    get server(): string;
    set server(value: string);
    get serverInput(): string | undefined;
}
export interface GoogleCloudRunV2WorkerPoolTemplateVolumesSecretItems {
    /**
    * Integer octal mode bits to use on this file, must be a value between 01 and 0777 (octal). If 0 or not set, the Volume's default mode will be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#mode GoogleCloudRunV2WorkerPool#mode}
    */
    readonly mode?: number;
    /**
    * The relative path of the secret in the container.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#path GoogleCloudRunV2WorkerPool#path}
    */
    readonly path: string;
    /**
    * The Cloud Secret Manager secret version. Can be 'latest' for the latest value or an integer for a specific version
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#version GoogleCloudRunV2WorkerPool#version}
    */
    readonly version?: string;
}
export declare function googleCloudRunV2WorkerPoolTemplateVolumesSecretItemsToTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateVolumesSecretItems | cdktf.IResolvable): any;
export declare function googleCloudRunV2WorkerPoolTemplateVolumesSecretItemsToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateVolumesSecretItems | cdktf.IResolvable): any;
export declare class GoogleCloudRunV2WorkerPoolTemplateVolumesSecretItemsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleCloudRunV2WorkerPoolTemplateVolumesSecretItems | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolTemplateVolumesSecretItems | cdktf.IResolvable | undefined);
    private _mode?;
    get mode(): number;
    set mode(value: number);
    resetMode(): void;
    get modeInput(): number | undefined;
    private _path?;
    get path(): string;
    set path(value: string);
    get pathInput(): string | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    resetVersion(): void;
    get versionInput(): string | undefined;
}
export declare class GoogleCloudRunV2WorkerPoolTemplateVolumesSecretItemsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleCloudRunV2WorkerPoolTemplateVolumesSecretItems[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleCloudRunV2WorkerPoolTemplateVolumesSecretItemsOutputReference;
}
export interface GoogleCloudRunV2WorkerPoolTemplateVolumesSecret {
    /**
    * Integer representation of mode bits to use on created files by default. Must be a value between 0000 and 0777 (octal), defaulting to 0444. Directories within the path are not affected by this setting.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#default_mode GoogleCloudRunV2WorkerPool#default_mode}
    */
    readonly defaultMode?: number;
    /**
    * The name of the secret in Cloud Secret Manager. Format: {secret} if the secret is in the same project. projects/{project}/secrets/{secret} if the secret is in a different project.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#secret GoogleCloudRunV2WorkerPool#secret}
    */
    readonly secret: string;
    /**
    * items block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#items GoogleCloudRunV2WorkerPool#items}
    */
    readonly items?: GoogleCloudRunV2WorkerPoolTemplateVolumesSecretItems[] | cdktf.IResolvable;
}
export declare function googleCloudRunV2WorkerPoolTemplateVolumesSecretToTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateVolumesSecretOutputReference | GoogleCloudRunV2WorkerPoolTemplateVolumesSecret): any;
export declare function googleCloudRunV2WorkerPoolTemplateVolumesSecretToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateVolumesSecretOutputReference | GoogleCloudRunV2WorkerPoolTemplateVolumesSecret): any;
export declare class GoogleCloudRunV2WorkerPoolTemplateVolumesSecretOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudRunV2WorkerPoolTemplateVolumesSecret | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolTemplateVolumesSecret | undefined);
    private _defaultMode?;
    get defaultMode(): number;
    set defaultMode(value: number);
    resetDefaultMode(): void;
    get defaultModeInput(): number | undefined;
    private _secret?;
    get secret(): string;
    set secret(value: string);
    get secretInput(): string | undefined;
    private _items;
    get items(): GoogleCloudRunV2WorkerPoolTemplateVolumesSecretItemsList;
    putItems(value: GoogleCloudRunV2WorkerPoolTemplateVolumesSecretItems[] | cdktf.IResolvable): void;
    resetItems(): void;
    get itemsInput(): cdktf.IResolvable | GoogleCloudRunV2WorkerPoolTemplateVolumesSecretItems[] | undefined;
}
export interface GoogleCloudRunV2WorkerPoolTemplateVolumes {
    /**
    * Volume's name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#name GoogleCloudRunV2WorkerPool#name}
    */
    readonly name: string;
    /**
    * cloud_sql_instance block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#cloud_sql_instance GoogleCloudRunV2WorkerPool#cloud_sql_instance}
    */
    readonly cloudSqlInstance?: GoogleCloudRunV2WorkerPoolTemplateVolumesCloudSqlInstance;
    /**
    * empty_dir block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#empty_dir GoogleCloudRunV2WorkerPool#empty_dir}
    */
    readonly emptyDir?: GoogleCloudRunV2WorkerPoolTemplateVolumesEmptyDir;
    /**
    * gcs block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#gcs GoogleCloudRunV2WorkerPool#gcs}
    */
    readonly gcs?: GoogleCloudRunV2WorkerPoolTemplateVolumesGcs;
    /**
    * nfs block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#nfs GoogleCloudRunV2WorkerPool#nfs}
    */
    readonly nfs?: GoogleCloudRunV2WorkerPoolTemplateVolumesNfs;
    /**
    * secret block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#secret GoogleCloudRunV2WorkerPool#secret}
    */
    readonly secret?: GoogleCloudRunV2WorkerPoolTemplateVolumesSecret;
}
export declare function googleCloudRunV2WorkerPoolTemplateVolumesToTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateVolumes | cdktf.IResolvable): any;
export declare function googleCloudRunV2WorkerPoolTemplateVolumesToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateVolumes | cdktf.IResolvable): any;
export declare class GoogleCloudRunV2WorkerPoolTemplateVolumesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleCloudRunV2WorkerPoolTemplateVolumes | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolTemplateVolumes | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _cloudSqlInstance;
    get cloudSqlInstance(): GoogleCloudRunV2WorkerPoolTemplateVolumesCloudSqlInstanceOutputReference;
    putCloudSqlInstance(value: GoogleCloudRunV2WorkerPoolTemplateVolumesCloudSqlInstance): void;
    resetCloudSqlInstance(): void;
    get cloudSqlInstanceInput(): GoogleCloudRunV2WorkerPoolTemplateVolumesCloudSqlInstance | undefined;
    private _emptyDir;
    get emptyDir(): GoogleCloudRunV2WorkerPoolTemplateVolumesEmptyDirOutputReference;
    putEmptyDir(value: GoogleCloudRunV2WorkerPoolTemplateVolumesEmptyDir): void;
    resetEmptyDir(): void;
    get emptyDirInput(): GoogleCloudRunV2WorkerPoolTemplateVolumesEmptyDir | undefined;
    private _gcs;
    get gcs(): GoogleCloudRunV2WorkerPoolTemplateVolumesGcsOutputReference;
    putGcs(value: GoogleCloudRunV2WorkerPoolTemplateVolumesGcs): void;
    resetGcs(): void;
    get gcsInput(): GoogleCloudRunV2WorkerPoolTemplateVolumesGcs | undefined;
    private _nfs;
    get nfs(): GoogleCloudRunV2WorkerPoolTemplateVolumesNfsOutputReference;
    putNfs(value: GoogleCloudRunV2WorkerPoolTemplateVolumesNfs): void;
    resetNfs(): void;
    get nfsInput(): GoogleCloudRunV2WorkerPoolTemplateVolumesNfs | undefined;
    private _secret;
    get secret(): GoogleCloudRunV2WorkerPoolTemplateVolumesSecretOutputReference;
    putSecret(value: GoogleCloudRunV2WorkerPoolTemplateVolumesSecret): void;
    resetSecret(): void;
    get secretInput(): GoogleCloudRunV2WorkerPoolTemplateVolumesSecret | undefined;
}
export declare class GoogleCloudRunV2WorkerPoolTemplateVolumesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleCloudRunV2WorkerPoolTemplateVolumes[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleCloudRunV2WorkerPoolTemplateVolumesOutputReference;
}
export interface GoogleCloudRunV2WorkerPoolTemplateVpcAccessNetworkInterfaces {
    /**
    * The VPC network that the Cloud Run resource will be able to send traffic to. At least one of network or subnetwork must be specified. If both
    * network and subnetwork are specified, the given VPC subnetwork must belong to the given VPC network. If network is not specified, it will be
    * looked up from the subnetwork.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#network GoogleCloudRunV2WorkerPool#network}
    */
    readonly network?: string;
    /**
    * The VPC subnetwork that the Cloud Run resource will get IPs from. At least one of network or subnetwork must be specified. If both
    * network and subnetwork are specified, the given VPC subnetwork must belong to the given VPC network. If subnetwork is not specified, the
    * subnetwork with the same name with the network will be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#subnetwork GoogleCloudRunV2WorkerPool#subnetwork}
    */
    readonly subnetwork?: string;
    /**
    * Network tags applied to this Cloud Run WorkerPool.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#tags GoogleCloudRunV2WorkerPool#tags}
    */
    readonly tags?: string[];
}
export declare function googleCloudRunV2WorkerPoolTemplateVpcAccessNetworkInterfacesToTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateVpcAccessNetworkInterfaces | cdktf.IResolvable): any;
export declare function googleCloudRunV2WorkerPoolTemplateVpcAccessNetworkInterfacesToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateVpcAccessNetworkInterfaces | cdktf.IResolvable): any;
export declare class GoogleCloudRunV2WorkerPoolTemplateVpcAccessNetworkInterfacesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleCloudRunV2WorkerPoolTemplateVpcAccessNetworkInterfaces | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolTemplateVpcAccessNetworkInterfaces | cdktf.IResolvable | undefined);
    private _network?;
    get network(): string;
    set network(value: string);
    resetNetwork(): void;
    get networkInput(): string | undefined;
    private _subnetwork?;
    get subnetwork(): string;
    set subnetwork(value: string);
    resetSubnetwork(): void;
    get subnetworkInput(): string | undefined;
    private _tags?;
    get tags(): string[];
    set tags(value: string[]);
    resetTags(): void;
    get tagsInput(): string[] | undefined;
}
export declare class GoogleCloudRunV2WorkerPoolTemplateVpcAccessNetworkInterfacesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleCloudRunV2WorkerPoolTemplateVpcAccessNetworkInterfaces[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleCloudRunV2WorkerPoolTemplateVpcAccessNetworkInterfacesOutputReference;
}
export interface GoogleCloudRunV2WorkerPoolTemplateVpcAccess {
    /**
    * Traffic VPC egress settings. Possible values: ["ALL_TRAFFIC", "PRIVATE_RANGES_ONLY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#egress GoogleCloudRunV2WorkerPool#egress}
    */
    readonly egress?: string;
    /**
    * network_interfaces block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#network_interfaces GoogleCloudRunV2WorkerPool#network_interfaces}
    */
    readonly networkInterfaces?: GoogleCloudRunV2WorkerPoolTemplateVpcAccessNetworkInterfaces[] | cdktf.IResolvable;
}
export declare function googleCloudRunV2WorkerPoolTemplateVpcAccessToTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateVpcAccessOutputReference | GoogleCloudRunV2WorkerPoolTemplateVpcAccess): any;
export declare function googleCloudRunV2WorkerPoolTemplateVpcAccessToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateVpcAccessOutputReference | GoogleCloudRunV2WorkerPoolTemplateVpcAccess): any;
export declare class GoogleCloudRunV2WorkerPoolTemplateVpcAccessOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudRunV2WorkerPoolTemplateVpcAccess | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolTemplateVpcAccess | undefined);
    private _egress?;
    get egress(): string;
    set egress(value: string);
    resetEgress(): void;
    get egressInput(): string | undefined;
    private _networkInterfaces;
    get networkInterfaces(): GoogleCloudRunV2WorkerPoolTemplateVpcAccessNetworkInterfacesList;
    putNetworkInterfaces(value: GoogleCloudRunV2WorkerPoolTemplateVpcAccessNetworkInterfaces[] | cdktf.IResolvable): void;
    resetNetworkInterfaces(): void;
    get networkInterfacesInput(): cdktf.IResolvable | GoogleCloudRunV2WorkerPoolTemplateVpcAccessNetworkInterfaces[] | undefined;
}
export interface GoogleCloudRunV2WorkerPoolTemplate {
    /**
    * Unstructured key value map that may be set by external tools to store and arbitrary metadata. They are not queryable and should be preserved when modifying objects.
    *
    * Cloud Run API v2 does not support annotations with 'run.googleapis.com', 'cloud.googleapis.com', 'serving.knative.dev', or 'autoscaling.knative.dev' namespaces, and they will be rejected.
    * All system annotations in v1 now have a corresponding field in v2 WorkerPoolRevisionTemplate.
    *
    * This field follows Kubernetes annotations' namespacing, limits, and rules.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#annotations GoogleCloudRunV2WorkerPool#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * A reference to a customer managed encryption key (CMEK) to use to encrypt this container image. For more information, go to https://cloud.google.com/run/docs/securing/using-cmek
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#encryption_key GoogleCloudRunV2WorkerPool#encryption_key}
    */
    readonly encryptionKey?: string;
    /**
    * The action to take if the encryption key is revoked. Possible values: ["PREVENT_NEW", "SHUTDOWN"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#encryption_key_revocation_action GoogleCloudRunV2WorkerPool#encryption_key_revocation_action}
    */
    readonly encryptionKeyRevocationAction?: string;
    /**
    * If encryptionKeyRevocationAction is SHUTDOWN, the duration before shutting down all instances. The minimum increment is 1 hour.
    *
    * A duration in seconds with up to nine fractional digits, ending with 's'. Example: "3.5s".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#encryption_key_shutdown_duration GoogleCloudRunV2WorkerPool#encryption_key_shutdown_duration}
    */
    readonly encryptionKeyShutdownDuration?: string;
    /**
    * True if GPU zonal redundancy is disabled on this revision.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#gpu_zonal_redundancy_disabled GoogleCloudRunV2WorkerPool#gpu_zonal_redundancy_disabled}
    */
    readonly gpuZonalRedundancyDisabled?: boolean | cdktf.IResolvable;
    /**
    * Unstructured key value map that can be used to organize and categorize objects. User-provided labels are shared with Google's billing system, so they can be used to filter, or break down billing charges by team, component, environment, state, etc.
    * For more information, visit https://cloud.google.com/resource-manager/docs/creating-managing-labels or https://cloud.google.com/run/docs/configuring/labels.
    *
    * Cloud Run API v2 does not support labels with 'run.googleapis.com', 'cloud.googleapis.com', 'serving.knative.dev', or 'autoscaling.knative.dev' namespaces, and they will be rejected.
    * All system labels in v1 now have a corresponding field in v2 WorkerPoolRevisionTemplate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#labels GoogleCloudRunV2WorkerPool#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The unique name for the revision. If this field is omitted, it will be automatically generated based on the WorkerPool name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#revision GoogleCloudRunV2WorkerPool#revision}
    */
    readonly revision?: string;
    /**
    * Email address of the IAM service account associated with the revision of the WorkerPool. The service account represents the identity of the running revision, and determines what permissions the revision has. If not provided, the revision will use the project's default service account.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#service_account GoogleCloudRunV2WorkerPool#service_account}
    */
    readonly serviceAccount?: string;
    /**
    * containers block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#containers GoogleCloudRunV2WorkerPool#containers}
    */
    readonly containers?: GoogleCloudRunV2WorkerPoolTemplateContainers[] | cdktf.IResolvable;
    /**
    * node_selector block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#node_selector GoogleCloudRunV2WorkerPool#node_selector}
    */
    readonly nodeSelector?: GoogleCloudRunV2WorkerPoolTemplateNodeSelector;
    /**
    * volumes block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#volumes GoogleCloudRunV2WorkerPool#volumes}
    */
    readonly volumes?: GoogleCloudRunV2WorkerPoolTemplateVolumes[] | cdktf.IResolvable;
    /**
    * vpc_access block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#vpc_access GoogleCloudRunV2WorkerPool#vpc_access}
    */
    readonly vpcAccess?: GoogleCloudRunV2WorkerPoolTemplateVpcAccess;
}
export declare function googleCloudRunV2WorkerPoolTemplateToTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateOutputReference | GoogleCloudRunV2WorkerPoolTemplate): any;
export declare function googleCloudRunV2WorkerPoolTemplateToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolTemplateOutputReference | GoogleCloudRunV2WorkerPoolTemplate): any;
export declare class GoogleCloudRunV2WorkerPoolTemplateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudRunV2WorkerPoolTemplate | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolTemplate | undefined);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    private _encryptionKey?;
    get encryptionKey(): string;
    set encryptionKey(value: string);
    resetEncryptionKey(): void;
    get encryptionKeyInput(): string | undefined;
    private _encryptionKeyRevocationAction?;
    get encryptionKeyRevocationAction(): string;
    set encryptionKeyRevocationAction(value: string);
    resetEncryptionKeyRevocationAction(): void;
    get encryptionKeyRevocationActionInput(): string | undefined;
    private _encryptionKeyShutdownDuration?;
    get encryptionKeyShutdownDuration(): string;
    set encryptionKeyShutdownDuration(value: string);
    resetEncryptionKeyShutdownDuration(): void;
    get encryptionKeyShutdownDurationInput(): string | undefined;
    private _gpuZonalRedundancyDisabled?;
    get gpuZonalRedundancyDisabled(): boolean | cdktf.IResolvable;
    set gpuZonalRedundancyDisabled(value: boolean | cdktf.IResolvable);
    resetGpuZonalRedundancyDisabled(): void;
    get gpuZonalRedundancyDisabledInput(): boolean | cdktf.IResolvable | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _revision?;
    get revision(): string;
    set revision(value: string);
    resetRevision(): void;
    get revisionInput(): string | undefined;
    private _serviceAccount?;
    get serviceAccount(): string;
    set serviceAccount(value: string);
    resetServiceAccount(): void;
    get serviceAccountInput(): string | undefined;
    private _containers;
    get containers(): GoogleCloudRunV2WorkerPoolTemplateContainersList;
    putContainers(value: GoogleCloudRunV2WorkerPoolTemplateContainers[] | cdktf.IResolvable): void;
    resetContainers(): void;
    get containersInput(): cdktf.IResolvable | GoogleCloudRunV2WorkerPoolTemplateContainers[] | undefined;
    private _nodeSelector;
    get nodeSelector(): GoogleCloudRunV2WorkerPoolTemplateNodeSelectorOutputReference;
    putNodeSelector(value: GoogleCloudRunV2WorkerPoolTemplateNodeSelector): void;
    resetNodeSelector(): void;
    get nodeSelectorInput(): GoogleCloudRunV2WorkerPoolTemplateNodeSelector | undefined;
    private _volumes;
    get volumes(): GoogleCloudRunV2WorkerPoolTemplateVolumesList;
    putVolumes(value: GoogleCloudRunV2WorkerPoolTemplateVolumes[] | cdktf.IResolvable): void;
    resetVolumes(): void;
    get volumesInput(): cdktf.IResolvable | GoogleCloudRunV2WorkerPoolTemplateVolumes[] | undefined;
    private _vpcAccess;
    get vpcAccess(): GoogleCloudRunV2WorkerPoolTemplateVpcAccessOutputReference;
    putVpcAccess(value: GoogleCloudRunV2WorkerPoolTemplateVpcAccess): void;
    resetVpcAccess(): void;
    get vpcAccessInput(): GoogleCloudRunV2WorkerPoolTemplateVpcAccess | undefined;
}
export interface GoogleCloudRunV2WorkerPoolTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#create GoogleCloudRunV2WorkerPool#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#delete GoogleCloudRunV2WorkerPool#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#update GoogleCloudRunV2WorkerPool#update}
    */
    readonly update?: string;
}
export declare function googleCloudRunV2WorkerPoolTimeoutsToTerraform(struct?: GoogleCloudRunV2WorkerPoolTimeouts | cdktf.IResolvable): any;
export declare function googleCloudRunV2WorkerPoolTimeoutsToHclTerraform(struct?: GoogleCloudRunV2WorkerPoolTimeouts | cdktf.IResolvable): any;
export declare class GoogleCloudRunV2WorkerPoolTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudRunV2WorkerPoolTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleCloudRunV2WorkerPoolTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool google_cloud_run_v2_worker_pool}
*/
export declare class GoogleCloudRunV2WorkerPool extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_cloud_run_v2_worker_pool";
    /**
    * Generates CDKTF code for importing a GoogleCloudRunV2WorkerPool resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleCloudRunV2WorkerPool to import
    * @param importFromId The id of the existing GoogleCloudRunV2WorkerPool that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleCloudRunV2WorkerPool to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_cloud_run_v2_worker_pool google_cloud_run_v2_worker_pool} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleCloudRunV2WorkerPoolConfig
    */
    constructor(scope: Construct, id: string, config: GoogleCloudRunV2WorkerPoolConfig);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    private _client?;
    get client(): string;
    set client(value: string);
    resetClient(): void;
    get clientInput(): string | undefined;
    private _clientVersion?;
    get clientVersion(): string;
    set clientVersion(value: string);
    resetClientVersion(): void;
    get clientVersionInput(): string | undefined;
    private _conditions;
    get conditions(): GoogleCloudRunV2WorkerPoolConditionsList;
    get createTime(): string;
    get creator(): string;
    private _customAudiences?;
    get customAudiences(): string[];
    set customAudiences(value: string[]);
    resetCustomAudiences(): void;
    get customAudiencesInput(): string[] | undefined;
    get deleteTime(): string;
    private _deletionProtection?;
    get deletionProtection(): boolean | cdktf.IResolvable;
    set deletionProtection(value: boolean | cdktf.IResolvable);
    resetDeletionProtection(): void;
    get deletionProtectionInput(): boolean | cdktf.IResolvable | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _effectiveAnnotations;
    get effectiveAnnotations(): cdktf.StringMap;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    get etag(): string;
    get expireTime(): string;
    get generation(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _instanceSplitStatuses;
    get instanceSplitStatuses(): GoogleCloudRunV2WorkerPoolInstanceSplitStatusesList;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    get lastModifier(): string;
    get latestCreatedRevision(): string;
    get latestReadyRevision(): string;
    private _launchStage?;
    get launchStage(): string;
    set launchStage(value: string);
    resetLaunchStage(): void;
    get launchStageInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get observedGeneration(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get reconciling(): cdktf.IResolvable;
    private _terminalCondition;
    get terminalCondition(): GoogleCloudRunV2WorkerPoolTerminalConditionList;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get uid(): string;
    get updateTime(): string;
    private _binaryAuthorization;
    get binaryAuthorization(): GoogleCloudRunV2WorkerPoolBinaryAuthorizationOutputReference;
    putBinaryAuthorization(value: GoogleCloudRunV2WorkerPoolBinaryAuthorization): void;
    resetBinaryAuthorization(): void;
    get binaryAuthorizationInput(): GoogleCloudRunV2WorkerPoolBinaryAuthorization | undefined;
    private _instanceSplits;
    get instanceSplits(): GoogleCloudRunV2WorkerPoolInstanceSplitsList;
    putInstanceSplits(value: GoogleCloudRunV2WorkerPoolInstanceSplits[] | cdktf.IResolvable): void;
    resetInstanceSplits(): void;
    get instanceSplitsInput(): cdktf.IResolvable | GoogleCloudRunV2WorkerPoolInstanceSplits[] | undefined;
    private _scaling;
    get scaling(): GoogleCloudRunV2WorkerPoolScalingOutputReference;
    putScaling(value: GoogleCloudRunV2WorkerPoolScaling): void;
    resetScaling(): void;
    get scalingInput(): GoogleCloudRunV2WorkerPoolScaling | undefined;
    private _template;
    get template(): GoogleCloudRunV2WorkerPoolTemplateOutputReference;
    putTemplate(value: GoogleCloudRunV2WorkerPoolTemplate): void;
    get templateInput(): GoogleCloudRunV2WorkerPoolTemplate | undefined;
    private _timeouts;
    get timeouts(): GoogleCloudRunV2WorkerPoolTimeoutsOutputReference;
    putTimeouts(value: GoogleCloudRunV2WorkerPoolTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleCloudRunV2WorkerPoolTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
