/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleComputeFutureReservationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Future timestamp when the FR auto-created reservations will be deleted by Compute Engine.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#auto_created_reservations_delete_time GoogleComputeFutureReservation#auto_created_reservations_delete_time}
    */
    readonly autoCreatedReservationsDeleteTime?: string;
    /**
    * Setting for enabling or disabling automatic deletion for auto-created reservation. If set to true, auto-created reservations will be deleted at Future Reservation's end time (default) or at user's defined timestamp if any of the [autoCreatedReservationsDeleteTime, autoCreatedReservationsDuration] values is specified. For keeping auto-created reservation indefinitely, this value should be set to false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#auto_delete_auto_created_reservations GoogleComputeFutureReservation#auto_delete_auto_created_reservations}
    */
    readonly autoDeleteAutoCreatedReservations?: boolean | cdktf.IResolvable;
    /**
    * Type of the deployment requested as part of future reservation. Possible values: ["DENSE", "FLEXIBLE"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#deployment_type GoogleComputeFutureReservation#deployment_type}
    */
    readonly deploymentType?: string;
    /**
    * An optional description of this resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#description GoogleComputeFutureReservation#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#id GoogleComputeFutureReservation#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of the resource. Provided by the client when the resource is
    * created. The name must be 1-63 characters long, and comply with
    * RFC1035. Specifically, the name must be 1-63 characters long and match
    * the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
    * first character must be a lowercase letter, and all following
    * characters must be a dash, lowercase letter, or digit, except the las
    * character, which cannot be a dash.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#name GoogleComputeFutureReservation#name}
    */
    readonly name: string;
    /**
    * Name prefix for the reservations to be created at the time of delivery. The name prefix must comply with RFC1035. Maximum allowed length for name prefix is 20. Automatically created reservations name format will be -date-####.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#name_prefix GoogleComputeFutureReservation#name_prefix}
    */
    readonly namePrefix?: string;
    /**
    * Planning state before being submitted for evaluation Possible values: ["DRAFT", "SUBMITTED"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#planning_status GoogleComputeFutureReservation#planning_status}
    */
    readonly planningStatus?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#project GoogleComputeFutureReservation#project}
    */
    readonly project?: string;
    /**
    * The reservation mode which determines reservation-termination behavior and expected pricing. Possible values: ["CALENDAR", "DEFAULT"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#reservation_mode GoogleComputeFutureReservation#reservation_mode}
    */
    readonly reservationMode?: string;
    /**
    * Name of reservations where the capacity is provisioned at the time of delivery of future reservations. If the reservation with the given name does not exist already, it is created automatically at the time of Approval with INACTIVE state till specified start-time. Either provide the reservationName or a namePrefix.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#reservation_name GoogleComputeFutureReservation#reservation_name}
    */
    readonly reservationName?: string;
    /**
    * Maintenance information for this reservation Possible values: ["GROUPED", "INDEPENDENT"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#scheduling_type GoogleComputeFutureReservation#scheduling_type}
    */
    readonly schedulingType?: string;
    /**
    * Indicates whether the auto-created reservation can be consumed by VMs with affinity for "any" reservation. If the field is set, then only VMs that target the reservation by name can consume from the delivered reservation.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#specific_reservation_required GoogleComputeFutureReservation#specific_reservation_required}
    */
    readonly specificReservationRequired?: boolean | cdktf.IResolvable;
    /**
    * auto_created_reservations_duration block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#auto_created_reservations_duration GoogleComputeFutureReservation#auto_created_reservations_duration}
    */
    readonly autoCreatedReservationsDuration?: GoogleComputeFutureReservationAutoCreatedReservationsDuration;
    /**
    * commitment_info block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#commitment_info GoogleComputeFutureReservation#commitment_info}
    */
    readonly commitmentInfo?: GoogleComputeFutureReservationCommitmentInfo;
    /**
    * share_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#share_settings GoogleComputeFutureReservation#share_settings}
    */
    readonly shareSettings?: GoogleComputeFutureReservationShareSettings;
    /**
    * specific_sku_properties block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#specific_sku_properties GoogleComputeFutureReservation#specific_sku_properties}
    */
    readonly specificSkuProperties?: GoogleComputeFutureReservationSpecificSkuProperties;
    /**
    * time_window block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#time_window GoogleComputeFutureReservation#time_window}
    */
    readonly timeWindow: GoogleComputeFutureReservationTimeWindow;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#timeouts GoogleComputeFutureReservation#timeouts}
    */
    readonly timeouts?: GoogleComputeFutureReservationTimeouts;
}
export interface GoogleComputeFutureReservationStatusLastKnownGoodStateExistingMatchingUsageInfo {
}
export declare function googleComputeFutureReservationStatusLastKnownGoodStateExistingMatchingUsageInfoToTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateExistingMatchingUsageInfo): any;
export declare function googleComputeFutureReservationStatusLastKnownGoodStateExistingMatchingUsageInfoToHclTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateExistingMatchingUsageInfo): any;
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateExistingMatchingUsageInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeFutureReservationStatusLastKnownGoodStateExistingMatchingUsageInfo | undefined;
    set internalValue(value: GoogleComputeFutureReservationStatusLastKnownGoodStateExistingMatchingUsageInfo | undefined);
    get count(): string;
    get timeStamp(): string;
}
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateExistingMatchingUsageInfoList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeFutureReservationStatusLastKnownGoodStateExistingMatchingUsageInfoOutputReference;
}
export interface GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettingsProjectMap {
}
export declare function googleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettingsProjectMapToTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettingsProjectMap): any;
export declare function googleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettingsProjectMapToHclTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettingsProjectMap): any;
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettingsProjectMapOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettingsProjectMap | undefined;
    set internalValue(value: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettingsProjectMap | undefined);
    get project(): string;
    get projectId(): string;
}
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettingsProjectMapList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettingsProjectMapOutputReference;
}
export interface GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettings {
}
export declare function googleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettingsToTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettings): any;
export declare function googleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettingsToHclTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettings): any;
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettings | undefined;
    set internalValue(value: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettings | undefined);
    private _projectMap;
    get projectMap(): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettingsProjectMapList;
    get projects(): string[];
    get shareType(): string;
}
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettingsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettingsOutputReference;
}
export interface GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesGuestAccelerators {
}
export declare function googleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesGuestAcceleratorsToTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesGuestAccelerators): any;
export declare function googleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesGuestAcceleratorsToHclTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesGuestAccelerators): any;
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesGuestAcceleratorsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesGuestAccelerators | undefined;
    set internalValue(value: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesGuestAccelerators | undefined);
    get acceleratorCount(): number;
    get acceleratorType(): string;
}
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesGuestAcceleratorsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesGuestAcceleratorsOutputReference;
}
export interface GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesLocalSsds {
}
export declare function googleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesLocalSsdsToTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesLocalSsds): any;
export declare function googleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesLocalSsdsToHclTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesLocalSsds): any;
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesLocalSsdsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesLocalSsds | undefined;
    set internalValue(value: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesLocalSsds | undefined);
    get diskSizeGb(): string;
    get interface(): string;
}
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesLocalSsdsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesLocalSsdsOutputReference;
}
export interface GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstanceProperties {
}
export declare function googleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesToTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstanceProperties): any;
export declare function googleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesToHclTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstanceProperties): any;
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstanceProperties | undefined;
    set internalValue(value: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstanceProperties | undefined);
    private _guestAccelerators;
    get guestAccelerators(): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesGuestAcceleratorsList;
    private _localSsds;
    get localSsds(): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesLocalSsdsList;
    get locationHint(): string;
    get machineType(): string;
    get maintenanceFreezeDurationHours(): number;
    get maintenanceInterval(): string;
    get minCpuPlatform(): string;
}
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesOutputReference;
}
export interface GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuProperties {
}
export declare function googleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesToTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuProperties): any;
export declare function googleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesToHclTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuProperties): any;
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuProperties | undefined;
    set internalValue(value: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuProperties | undefined);
    private _instanceProperties;
    get instanceProperties(): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesInstancePropertiesList;
    get sourceInstanceTemplate(): string;
    get totalCount(): string;
}
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesOutputReference;
}
export interface GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindowDuration {
}
export declare function googleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindowDurationToTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindowDuration): any;
export declare function googleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindowDurationToHclTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindowDuration): any;
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindowDurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindowDuration | undefined;
    set internalValue(value: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindowDuration | undefined);
    get nanos(): number;
    get seconds(): string;
}
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindowDurationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindowDurationOutputReference;
}
export interface GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindow {
}
export declare function googleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindowToTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindow): any;
export declare function googleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindowToHclTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindow): any;
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindowOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindow | undefined;
    set internalValue(value: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindow | undefined);
    private _duration;
    get duration(): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindowDurationList;
    get endTime(): string;
    get startTime(): string;
}
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindowList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindowOutputReference;
}
export interface GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecs {
}
export declare function googleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsToTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecs): any;
export declare function googleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsToHclTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecs): any;
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecs | undefined;
    set internalValue(value: GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecs | undefined);
    private _shareSettings;
    get shareSettings(): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsShareSettingsList;
    private _specificSkuProperties;
    get specificSkuProperties(): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsSpecificSkuPropertiesList;
    private _timeWindow;
    get timeWindow(): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsTimeWindowList;
}
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsOutputReference;
}
export interface GoogleComputeFutureReservationStatusLastKnownGoodState {
}
export declare function googleComputeFutureReservationStatusLastKnownGoodStateToTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodState): any;
export declare function googleComputeFutureReservationStatusLastKnownGoodStateToHclTerraform(struct?: GoogleComputeFutureReservationStatusLastKnownGoodState): any;
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeFutureReservationStatusLastKnownGoodState | undefined;
    set internalValue(value: GoogleComputeFutureReservationStatusLastKnownGoodState | undefined);
    get description(): string;
    private _existingMatchingUsageInfo;
    get existingMatchingUsageInfo(): GoogleComputeFutureReservationStatusLastKnownGoodStateExistingMatchingUsageInfoList;
    private _futureReservationSpecs;
    get futureReservationSpecs(): GoogleComputeFutureReservationStatusLastKnownGoodStateFutureReservationSpecsList;
    get lockTime(): string;
    get namePrefix(): string;
    get procurementStatus(): string;
}
export declare class GoogleComputeFutureReservationStatusLastKnownGoodStateList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeFutureReservationStatusLastKnownGoodStateOutputReference;
}
export interface GoogleComputeFutureReservationStatusSpecificSkuProperties {
}
export declare function googleComputeFutureReservationStatusSpecificSkuPropertiesToTerraform(struct?: GoogleComputeFutureReservationStatusSpecificSkuProperties): any;
export declare function googleComputeFutureReservationStatusSpecificSkuPropertiesToHclTerraform(struct?: GoogleComputeFutureReservationStatusSpecificSkuProperties): any;
export declare class GoogleComputeFutureReservationStatusSpecificSkuPropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeFutureReservationStatusSpecificSkuProperties | undefined;
    set internalValue(value: GoogleComputeFutureReservationStatusSpecificSkuProperties | undefined);
    get sourceInstanceTemplateId(): string;
}
export declare class GoogleComputeFutureReservationStatusSpecificSkuPropertiesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeFutureReservationStatusSpecificSkuPropertiesOutputReference;
}
export interface GoogleComputeFutureReservationStatus {
}
export declare function googleComputeFutureReservationStatusToTerraform(struct?: GoogleComputeFutureReservationStatus): any;
export declare function googleComputeFutureReservationStatusToHclTerraform(struct?: GoogleComputeFutureReservationStatus): any;
export declare class GoogleComputeFutureReservationStatusOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeFutureReservationStatus | undefined;
    set internalValue(value: GoogleComputeFutureReservationStatus | undefined);
    get amendmentStatus(): string;
    get autoCreatedReservations(): string[];
    get fulfilledCount(): string;
    private _lastKnownGoodState;
    get lastKnownGoodState(): GoogleComputeFutureReservationStatusLastKnownGoodStateList;
    get lockTime(): string;
    get procurementStatus(): string;
    private _specificSkuProperties;
    get specificSkuProperties(): GoogleComputeFutureReservationStatusSpecificSkuPropertiesList;
}
export declare class GoogleComputeFutureReservationStatusList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeFutureReservationStatusOutputReference;
}
export interface GoogleComputeFutureReservationAutoCreatedReservationsDuration {
    /**
    * Span of time that's a fraction of a second at nanosecond resolution. Durations less than one second are represented with a 0 seconds field and a positive nanos field. Must be from 0 to 999,999,999 inclusive.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#nanos GoogleComputeFutureReservation#nanos}
    */
    readonly nanos?: number;
    /**
    * Span of time at a resolution of a second. Must be from 0 to 315,576,000,000 inclusive.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#seconds GoogleComputeFutureReservation#seconds}
    */
    readonly seconds?: string;
}
export declare function googleComputeFutureReservationAutoCreatedReservationsDurationToTerraform(struct?: GoogleComputeFutureReservationAutoCreatedReservationsDurationOutputReference | GoogleComputeFutureReservationAutoCreatedReservationsDuration): any;
export declare function googleComputeFutureReservationAutoCreatedReservationsDurationToHclTerraform(struct?: GoogleComputeFutureReservationAutoCreatedReservationsDurationOutputReference | GoogleComputeFutureReservationAutoCreatedReservationsDuration): any;
export declare class GoogleComputeFutureReservationAutoCreatedReservationsDurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputeFutureReservationAutoCreatedReservationsDuration | undefined;
    set internalValue(value: GoogleComputeFutureReservationAutoCreatedReservationsDuration | undefined);
    private _nanos?;
    get nanos(): number;
    set nanos(value: number);
    resetNanos(): void;
    get nanosInput(): number | undefined;
    private _seconds?;
    get seconds(): string;
    set seconds(value: string);
    resetSeconds(): void;
    get secondsInput(): string | undefined;
}
export interface GoogleComputeFutureReservationCommitmentInfo {
    /**
    * name of the commitment where capacity is being delivered to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#commitment_name GoogleComputeFutureReservation#commitment_name}
    */
    readonly commitmentName?: string;
    /**
    * Indicates if a Commitment needs to be created as part of FR delivery. If this field is not present, then no commitment needs to be created. Possible values: ["INVALID", "THIRTY_SIX_MONTH", "TWELVE_MONTH"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#commitment_plan GoogleComputeFutureReservation#commitment_plan}
    */
    readonly commitmentPlan?: string;
    /**
    * Only applicable if FR is delivering to the same reservation. If set, all parent commitments will be extended to match the end date of the plan for this commitment. Possible values: ["EXTEND"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#previous_commitment_terms GoogleComputeFutureReservation#previous_commitment_terms}
    */
    readonly previousCommitmentTerms?: string;
}
export declare function googleComputeFutureReservationCommitmentInfoToTerraform(struct?: GoogleComputeFutureReservationCommitmentInfoOutputReference | GoogleComputeFutureReservationCommitmentInfo): any;
export declare function googleComputeFutureReservationCommitmentInfoToHclTerraform(struct?: GoogleComputeFutureReservationCommitmentInfoOutputReference | GoogleComputeFutureReservationCommitmentInfo): any;
export declare class GoogleComputeFutureReservationCommitmentInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputeFutureReservationCommitmentInfo | undefined;
    set internalValue(value: GoogleComputeFutureReservationCommitmentInfo | undefined);
    private _commitmentName?;
    get commitmentName(): string;
    set commitmentName(value: string);
    resetCommitmentName(): void;
    get commitmentNameInput(): string | undefined;
    private _commitmentPlan?;
    get commitmentPlan(): string;
    set commitmentPlan(value: string);
    resetCommitmentPlan(): void;
    get commitmentPlanInput(): string | undefined;
    private _previousCommitmentTerms?;
    get previousCommitmentTerms(): string;
    set previousCommitmentTerms(value: string);
    resetPreviousCommitmentTerms(): void;
    get previousCommitmentTermsInput(): string | undefined;
}
export interface GoogleComputeFutureReservationShareSettingsProjectMap {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#id GoogleComputeFutureReservation#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * The project ID, should be same as the key of this project config in the parent map.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#project_id GoogleComputeFutureReservation#project_id}
    */
    readonly projectId?: string;
}
export declare function googleComputeFutureReservationShareSettingsProjectMapToTerraform(struct?: GoogleComputeFutureReservationShareSettingsProjectMap | cdktf.IResolvable): any;
export declare function googleComputeFutureReservationShareSettingsProjectMapToHclTerraform(struct?: GoogleComputeFutureReservationShareSettingsProjectMap | cdktf.IResolvable): any;
export declare class GoogleComputeFutureReservationShareSettingsProjectMapOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeFutureReservationShareSettingsProjectMap | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComputeFutureReservationShareSettingsProjectMap | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
}
export declare class GoogleComputeFutureReservationShareSettingsProjectMapList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleComputeFutureReservationShareSettingsProjectMap[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeFutureReservationShareSettingsProjectMapOutputReference;
}
export interface GoogleComputeFutureReservationShareSettings {
    /**
    * list of Project names to specify consumer projects for this shared-reservation. This is only valid when shareType's value is SPECIFIC_PROJECTS.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#projects GoogleComputeFutureReservation#projects}
    */
    readonly projects?: string[];
    /**
    * Type of sharing for this future reservation. Possible values: ["LOCAL", "SPECIFIC_PROJECTS"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#share_type GoogleComputeFutureReservation#share_type}
    */
    readonly shareType?: string;
    /**
    * project_map block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#project_map GoogleComputeFutureReservation#project_map}
    */
    readonly projectMap?: GoogleComputeFutureReservationShareSettingsProjectMap[] | cdktf.IResolvable;
}
export declare function googleComputeFutureReservationShareSettingsToTerraform(struct?: GoogleComputeFutureReservationShareSettingsOutputReference | GoogleComputeFutureReservationShareSettings): any;
export declare function googleComputeFutureReservationShareSettingsToHclTerraform(struct?: GoogleComputeFutureReservationShareSettingsOutputReference | GoogleComputeFutureReservationShareSettings): any;
export declare class GoogleComputeFutureReservationShareSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputeFutureReservationShareSettings | undefined;
    set internalValue(value: GoogleComputeFutureReservationShareSettings | undefined);
    private _projects?;
    get projects(): string[];
    set projects(value: string[]);
    resetProjects(): void;
    get projectsInput(): string[] | undefined;
    private _shareType?;
    get shareType(): string;
    set shareType(value: string);
    resetShareType(): void;
    get shareTypeInput(): string | undefined;
    private _projectMap;
    get projectMap(): GoogleComputeFutureReservationShareSettingsProjectMapList;
    putProjectMap(value: GoogleComputeFutureReservationShareSettingsProjectMap[] | cdktf.IResolvable): void;
    resetProjectMap(): void;
    get projectMapInput(): cdktf.IResolvable | GoogleComputeFutureReservationShareSettingsProjectMap[] | undefined;
}
export interface GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesGuestAccelerators {
    /**
    * The number of the guest accelerator cards exposed to this instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#accelerator_count GoogleComputeFutureReservation#accelerator_count}
    */
    readonly acceleratorCount?: number;
    /**
    * Full or partial URL of the accelerator type resource to attach to this instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#accelerator_type GoogleComputeFutureReservation#accelerator_type}
    */
    readonly acceleratorType?: string;
}
export declare function googleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesGuestAcceleratorsToTerraform(struct?: GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesGuestAccelerators | cdktf.IResolvable): any;
export declare function googleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesGuestAcceleratorsToHclTerraform(struct?: GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesGuestAccelerators | cdktf.IResolvable): any;
export declare class GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesGuestAcceleratorsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesGuestAccelerators | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesGuestAccelerators | cdktf.IResolvable | undefined);
    private _acceleratorCount?;
    get acceleratorCount(): number;
    set acceleratorCount(value: number);
    resetAcceleratorCount(): void;
    get acceleratorCountInput(): number | undefined;
    private _acceleratorType?;
    get acceleratorType(): string;
    set acceleratorType(value: string);
    resetAcceleratorType(): void;
    get acceleratorTypeInput(): string | undefined;
}
export declare class GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesGuestAcceleratorsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesGuestAccelerators[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesGuestAcceleratorsOutputReference;
}
export interface GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesLocalSsds {
    /**
    * Specifies the size of the disk in base-2 GB.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#disk_size_gb GoogleComputeFutureReservation#disk_size_gb}
    */
    readonly diskSizeGb?: string;
    /**
    * Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default is SCSI. Possible values: ["SCSI", "NVME"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#interface GoogleComputeFutureReservation#interface}
    */
    readonly interface?: string;
}
export declare function googleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesLocalSsdsToTerraform(struct?: GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesLocalSsds | cdktf.IResolvable): any;
export declare function googleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesLocalSsdsToHclTerraform(struct?: GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesLocalSsds | cdktf.IResolvable): any;
export declare class GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesLocalSsdsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesLocalSsds | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesLocalSsds | cdktf.IResolvable | undefined);
    private _diskSizeGb?;
    get diskSizeGb(): string;
    set diskSizeGb(value: string);
    resetDiskSizeGb(): void;
    get diskSizeGbInput(): string | undefined;
    private _interface?;
    get interface(): string;
    set interface(value: string);
    resetInterface(): void;
    get interfaceInput(): string | undefined;
}
export declare class GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesLocalSsdsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesLocalSsds[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesLocalSsdsOutputReference;
}
export interface GoogleComputeFutureReservationSpecificSkuPropertiesInstanceProperties {
    /**
    * An opaque location hint used to place the allocation close to other resources. This field is for use by internal tools that use the public API.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#location_hint GoogleComputeFutureReservation#location_hint}
    */
    readonly locationHint?: string;
    /**
    * Specifies type of machine (name only) which has fixed number of vCPUs and fixed amount of memory. This also includes specifying custom machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#machine_type GoogleComputeFutureReservation#machine_type}
    */
    readonly machineType?: string;
    /**
    * Specifies the number of hours after reservation creation where instances using the reservation won't be scheduled for maintenance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#maintenance_freeze_duration_hours GoogleComputeFutureReservation#maintenance_freeze_duration_hours}
    */
    readonly maintenanceFreezeDurationHours?: number;
    /**
    * Specifies the frequency of planned maintenance events. The accepted values are: PERIODIC Possible values: ["PERIODIC"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#maintenance_interval GoogleComputeFutureReservation#maintenance_interval}
    */
    readonly maintenanceInterval?: string;
    /**
    * Minimum cpu platform the reservation.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#min_cpu_platform GoogleComputeFutureReservation#min_cpu_platform}
    */
    readonly minCpuPlatform?: string;
    /**
    * guest_accelerators block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#guest_accelerators GoogleComputeFutureReservation#guest_accelerators}
    */
    readonly guestAccelerators?: GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesGuestAccelerators[] | cdktf.IResolvable;
    /**
    * local_ssds block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#local_ssds GoogleComputeFutureReservation#local_ssds}
    */
    readonly localSsds?: GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesLocalSsds[] | cdktf.IResolvable;
}
export declare function googleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesToTerraform(struct?: GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesOutputReference | GoogleComputeFutureReservationSpecificSkuPropertiesInstanceProperties): any;
export declare function googleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesToHclTerraform(struct?: GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesOutputReference | GoogleComputeFutureReservationSpecificSkuPropertiesInstanceProperties): any;
export declare class GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputeFutureReservationSpecificSkuPropertiesInstanceProperties | undefined;
    set internalValue(value: GoogleComputeFutureReservationSpecificSkuPropertiesInstanceProperties | undefined);
    private _locationHint?;
    get locationHint(): string;
    set locationHint(value: string);
    resetLocationHint(): void;
    get locationHintInput(): string | undefined;
    private _machineType?;
    get machineType(): string;
    set machineType(value: string);
    resetMachineType(): void;
    get machineTypeInput(): string | undefined;
    private _maintenanceFreezeDurationHours?;
    get maintenanceFreezeDurationHours(): number;
    set maintenanceFreezeDurationHours(value: number);
    resetMaintenanceFreezeDurationHours(): void;
    get maintenanceFreezeDurationHoursInput(): number | undefined;
    private _maintenanceInterval?;
    get maintenanceInterval(): string;
    set maintenanceInterval(value: string);
    resetMaintenanceInterval(): void;
    get maintenanceIntervalInput(): string | undefined;
    private _minCpuPlatform?;
    get minCpuPlatform(): string;
    set minCpuPlatform(value: string);
    resetMinCpuPlatform(): void;
    get minCpuPlatformInput(): string | undefined;
    private _guestAccelerators;
    get guestAccelerators(): GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesGuestAcceleratorsList;
    putGuestAccelerators(value: GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesGuestAccelerators[] | cdktf.IResolvable): void;
    resetGuestAccelerators(): void;
    get guestAcceleratorsInput(): cdktf.IResolvable | GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesGuestAccelerators[] | undefined;
    private _localSsds;
    get localSsds(): GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesLocalSsdsList;
    putLocalSsds(value: GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesLocalSsds[] | cdktf.IResolvable): void;
    resetLocalSsds(): void;
    get localSsdsInput(): cdktf.IResolvable | GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesLocalSsds[] | undefined;
}
export interface GoogleComputeFutureReservationSpecificSkuProperties {
    /**
    * The instance template that will be used to populate the ReservedInstanceProperties of the future reservation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#source_instance_template GoogleComputeFutureReservation#source_instance_template}
    */
    readonly sourceInstanceTemplate?: string;
    /**
    * Total number of instances for which capacity assurance is requested at a future time period.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#total_count GoogleComputeFutureReservation#total_count}
    */
    readonly totalCount?: string;
    /**
    * instance_properties block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#instance_properties GoogleComputeFutureReservation#instance_properties}
    */
    readonly instanceProperties?: GoogleComputeFutureReservationSpecificSkuPropertiesInstanceProperties;
}
export declare function googleComputeFutureReservationSpecificSkuPropertiesToTerraform(struct?: GoogleComputeFutureReservationSpecificSkuPropertiesOutputReference | GoogleComputeFutureReservationSpecificSkuProperties): any;
export declare function googleComputeFutureReservationSpecificSkuPropertiesToHclTerraform(struct?: GoogleComputeFutureReservationSpecificSkuPropertiesOutputReference | GoogleComputeFutureReservationSpecificSkuProperties): any;
export declare class GoogleComputeFutureReservationSpecificSkuPropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputeFutureReservationSpecificSkuProperties | undefined;
    set internalValue(value: GoogleComputeFutureReservationSpecificSkuProperties | undefined);
    private _sourceInstanceTemplate?;
    get sourceInstanceTemplate(): string;
    set sourceInstanceTemplate(value: string);
    resetSourceInstanceTemplate(): void;
    get sourceInstanceTemplateInput(): string | undefined;
    private _totalCount?;
    get totalCount(): string;
    set totalCount(value: string);
    resetTotalCount(): void;
    get totalCountInput(): string | undefined;
    private _instanceProperties;
    get instanceProperties(): GoogleComputeFutureReservationSpecificSkuPropertiesInstancePropertiesOutputReference;
    putInstanceProperties(value: GoogleComputeFutureReservationSpecificSkuPropertiesInstanceProperties): void;
    resetInstanceProperties(): void;
    get instancePropertiesInput(): GoogleComputeFutureReservationSpecificSkuPropertiesInstanceProperties | undefined;
}
export interface GoogleComputeFutureReservationTimeWindowDuration {
    /**
    * Span of time that's a fraction of a second at nanosecond resolution.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#nanos GoogleComputeFutureReservation#nanos}
    */
    readonly nanos?: number;
    /**
    * Span of time at a resolution of a second. Must be from 0 to 315,576,000,000 inclusive.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#seconds GoogleComputeFutureReservation#seconds}
    */
    readonly seconds?: string;
}
export declare function googleComputeFutureReservationTimeWindowDurationToTerraform(struct?: GoogleComputeFutureReservationTimeWindowDurationOutputReference | GoogleComputeFutureReservationTimeWindowDuration): any;
export declare function googleComputeFutureReservationTimeWindowDurationToHclTerraform(struct?: GoogleComputeFutureReservationTimeWindowDurationOutputReference | GoogleComputeFutureReservationTimeWindowDuration): any;
export declare class GoogleComputeFutureReservationTimeWindowDurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputeFutureReservationTimeWindowDuration | undefined;
    set internalValue(value: GoogleComputeFutureReservationTimeWindowDuration | undefined);
    private _nanos?;
    get nanos(): number;
    set nanos(value: number);
    resetNanos(): void;
    get nanosInput(): number | undefined;
    private _seconds?;
    get seconds(): string;
    set seconds(value: string);
    resetSeconds(): void;
    get secondsInput(): string | undefined;
}
export interface GoogleComputeFutureReservationTimeWindow {
    /**
    * End time of the future reservation in RFC3339 format.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#end_time GoogleComputeFutureReservation#end_time}
    */
    readonly endTime?: string;
    /**
    * Start time of the future reservation in RFC3339 format.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#start_time GoogleComputeFutureReservation#start_time}
    */
    readonly startTime: string;
    /**
    * duration block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#duration GoogleComputeFutureReservation#duration}
    */
    readonly duration?: GoogleComputeFutureReservationTimeWindowDuration;
}
export declare function googleComputeFutureReservationTimeWindowToTerraform(struct?: GoogleComputeFutureReservationTimeWindowOutputReference | GoogleComputeFutureReservationTimeWindow): any;
export declare function googleComputeFutureReservationTimeWindowToHclTerraform(struct?: GoogleComputeFutureReservationTimeWindowOutputReference | GoogleComputeFutureReservationTimeWindow): any;
export declare class GoogleComputeFutureReservationTimeWindowOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputeFutureReservationTimeWindow | undefined;
    set internalValue(value: GoogleComputeFutureReservationTimeWindow | undefined);
    private _endTime?;
    get endTime(): string;
    set endTime(value: string);
    resetEndTime(): void;
    get endTimeInput(): string | undefined;
    private _startTime?;
    get startTime(): string;
    set startTime(value: string);
    get startTimeInput(): string | undefined;
    private _duration;
    get duration(): GoogleComputeFutureReservationTimeWindowDurationOutputReference;
    putDuration(value: GoogleComputeFutureReservationTimeWindowDuration): void;
    resetDuration(): void;
    get durationInput(): GoogleComputeFutureReservationTimeWindowDuration | undefined;
}
export interface GoogleComputeFutureReservationTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#create GoogleComputeFutureReservation#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#delete GoogleComputeFutureReservation#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#update GoogleComputeFutureReservation#update}
    */
    readonly update?: string;
}
export declare function googleComputeFutureReservationTimeoutsToTerraform(struct?: GoogleComputeFutureReservationTimeouts | cdktf.IResolvable): any;
export declare function googleComputeFutureReservationTimeoutsToHclTerraform(struct?: GoogleComputeFutureReservationTimeouts | cdktf.IResolvable): any;
export declare class GoogleComputeFutureReservationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputeFutureReservationTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComputeFutureReservationTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation google_compute_future_reservation}
*/
export declare class GoogleComputeFutureReservation extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_compute_future_reservation";
    /**
    * Generates CDKTF code for importing a GoogleComputeFutureReservation resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleComputeFutureReservation to import
    * @param importFromId The id of the existing GoogleComputeFutureReservation that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleComputeFutureReservation to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_compute_future_reservation google_compute_future_reservation} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleComputeFutureReservationConfig
    */
    constructor(scope: Construct, id: string, config: GoogleComputeFutureReservationConfig);
    private _autoCreatedReservationsDeleteTime?;
    get autoCreatedReservationsDeleteTime(): string;
    set autoCreatedReservationsDeleteTime(value: string);
    resetAutoCreatedReservationsDeleteTime(): void;
    get autoCreatedReservationsDeleteTimeInput(): string | undefined;
    private _autoDeleteAutoCreatedReservations?;
    get autoDeleteAutoCreatedReservations(): boolean | cdktf.IResolvable;
    set autoDeleteAutoCreatedReservations(value: boolean | cdktf.IResolvable);
    resetAutoDeleteAutoCreatedReservations(): void;
    get autoDeleteAutoCreatedReservationsInput(): boolean | cdktf.IResolvable | undefined;
    get creationTimestamp(): string;
    private _deploymentType?;
    get deploymentType(): string;
    set deploymentType(value: string);
    resetDeploymentType(): void;
    get deploymentTypeInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _namePrefix?;
    get namePrefix(): string;
    set namePrefix(value: string);
    resetNamePrefix(): void;
    get namePrefixInput(): string | undefined;
    private _planningStatus?;
    get planningStatus(): string;
    set planningStatus(value: string);
    resetPlanningStatus(): void;
    get planningStatusInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _reservationMode?;
    get reservationMode(): string;
    set reservationMode(value: string);
    resetReservationMode(): void;
    get reservationModeInput(): string | undefined;
    private _reservationName?;
    get reservationName(): string;
    set reservationName(value: string);
    resetReservationName(): void;
    get reservationNameInput(): string | undefined;
    private _schedulingType?;
    get schedulingType(): string;
    set schedulingType(value: string);
    resetSchedulingType(): void;
    get schedulingTypeInput(): string | undefined;
    get selfLink(): string;
    get selfLinkWithId(): string;
    private _specificReservationRequired?;
    get specificReservationRequired(): boolean | cdktf.IResolvable;
    set specificReservationRequired(value: boolean | cdktf.IResolvable);
    resetSpecificReservationRequired(): void;
    get specificReservationRequiredInput(): boolean | cdktf.IResolvable | undefined;
    private _status;
    get status(): GoogleComputeFutureReservationStatusList;
    get zone(): string;
    private _autoCreatedReservationsDuration;
    get autoCreatedReservationsDuration(): GoogleComputeFutureReservationAutoCreatedReservationsDurationOutputReference;
    putAutoCreatedReservationsDuration(value: GoogleComputeFutureReservationAutoCreatedReservationsDuration): void;
    resetAutoCreatedReservationsDuration(): void;
    get autoCreatedReservationsDurationInput(): GoogleComputeFutureReservationAutoCreatedReservationsDuration | undefined;
    private _commitmentInfo;
    get commitmentInfo(): GoogleComputeFutureReservationCommitmentInfoOutputReference;
    putCommitmentInfo(value: GoogleComputeFutureReservationCommitmentInfo): void;
    resetCommitmentInfo(): void;
    get commitmentInfoInput(): GoogleComputeFutureReservationCommitmentInfo | undefined;
    private _shareSettings;
    get shareSettings(): GoogleComputeFutureReservationShareSettingsOutputReference;
    putShareSettings(value: GoogleComputeFutureReservationShareSettings): void;
    resetShareSettings(): void;
    get shareSettingsInput(): GoogleComputeFutureReservationShareSettings | undefined;
    private _specificSkuProperties;
    get specificSkuProperties(): GoogleComputeFutureReservationSpecificSkuPropertiesOutputReference;
    putSpecificSkuProperties(value: GoogleComputeFutureReservationSpecificSkuProperties): void;
    resetSpecificSkuProperties(): void;
    get specificSkuPropertiesInput(): GoogleComputeFutureReservationSpecificSkuProperties | undefined;
    private _timeWindow;
    get timeWindow(): GoogleComputeFutureReservationTimeWindowOutputReference;
    putTimeWindow(value: GoogleComputeFutureReservationTimeWindow): void;
    get timeWindowInput(): GoogleComputeFutureReservationTimeWindow | undefined;
    private _timeouts;
    get timeouts(): GoogleComputeFutureReservationTimeoutsOutputReference;
    putTimeouts(value: GoogleComputeFutureReservationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleComputeFutureReservationTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
