/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleDataplexEntryConfig extends cdktf.TerraformMetaArguments {
    /**
    * The entry group id of the entry group the entry will be created in.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#entry_group_id GoogleDataplexEntry#entry_group_id}
    */
    readonly entryGroupId?: string;
    /**
    * The entry id of the entry.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#entry_id GoogleDataplexEntry#entry_id}
    */
    readonly entryId?: string;
    /**
    * The relative resource name of the entry type that was used to create this entry, in the format projects/{project_number}/locations/{locationId}/entryTypes/{entryTypeId}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#entry_type GoogleDataplexEntry#entry_type}
    */
    readonly entryType: string;
    /**
    * A name for the entry that can be referenced by an external system. For more information, see https://cloud.google.com/dataplex/docs/fully-qualified-names.
    * The maximum size of the field is 4000 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#fully_qualified_name GoogleDataplexEntry#fully_qualified_name}
    */
    readonly fullyQualifiedName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#id GoogleDataplexEntry#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The location where entry will be created.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#location GoogleDataplexEntry#location}
    */
    readonly location?: string;
    /**
    * The resource name of the parent entry, in the format projects/{project_number}/locations/{locationId}/entryGroups/{entryGroupId}/entries/{entryId}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#parent_entry GoogleDataplexEntry#parent_entry}
    */
    readonly parentEntry?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#project GoogleDataplexEntry#project}
    */
    readonly project?: string;
    /**
    * aspects block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#aspects GoogleDataplexEntry#aspects}
    */
    readonly aspects?: GoogleDataplexEntryAspects[] | cdktf.IResolvable;
    /**
    * entry_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#entry_source GoogleDataplexEntry#entry_source}
    */
    readonly entrySource?: GoogleDataplexEntryEntrySource;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#timeouts GoogleDataplexEntry#timeouts}
    */
    readonly timeouts?: GoogleDataplexEntryTimeouts;
}
export interface GoogleDataplexEntryAspectsAspect {
    /**
    * The content of the aspect in JSON form, according to its aspect type schema. The maximum size of the field is 120KB (encoded as UTF-8).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#data GoogleDataplexEntry#data}
    */
    readonly data: string;
}
export declare function googleDataplexEntryAspectsAspectToTerraform(struct?: GoogleDataplexEntryAspectsAspectOutputReference | GoogleDataplexEntryAspectsAspect): any;
export declare function googleDataplexEntryAspectsAspectToHclTerraform(struct?: GoogleDataplexEntryAspectsAspectOutputReference | GoogleDataplexEntryAspectsAspect): any;
export declare class GoogleDataplexEntryAspectsAspectOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataplexEntryAspectsAspect | undefined;
    set internalValue(value: GoogleDataplexEntryAspectsAspect | undefined);
    get aspectType(): string;
    get createTime(): string;
    private _data?;
    get data(): string;
    set data(value: string);
    get dataInput(): string | undefined;
    get path(): string;
    get updateTime(): string;
}
export interface GoogleDataplexEntryAspects {
    /**
    * Depending on how the aspect is attached to the entry, the format of the aspect key can be one of the following:
    *
    * If the aspect is attached directly to the entry: {project_number}.{locationId}.{aspectTypeId}
    * If the aspect is attached to an entry's path: {project_number}.{locationId}.{aspectTypeId}@{path}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#aspect_key GoogleDataplexEntry#aspect_key}
    */
    readonly aspectKey: string;
    /**
    * aspect block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#aspect GoogleDataplexEntry#aspect}
    */
    readonly aspect: GoogleDataplexEntryAspectsAspect;
}
export declare function googleDataplexEntryAspectsToTerraform(struct?: GoogleDataplexEntryAspects | cdktf.IResolvable): any;
export declare function googleDataplexEntryAspectsToHclTerraform(struct?: GoogleDataplexEntryAspects | cdktf.IResolvable): any;
export declare class GoogleDataplexEntryAspectsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexEntryAspects | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDataplexEntryAspects | cdktf.IResolvable | undefined);
    private _aspectKey?;
    get aspectKey(): string;
    set aspectKey(value: string);
    get aspectKeyInput(): string | undefined;
    private _aspect;
    get aspect(): GoogleDataplexEntryAspectsAspectOutputReference;
    putAspect(value: GoogleDataplexEntryAspectsAspect): void;
    get aspectInput(): GoogleDataplexEntryAspectsAspect | undefined;
}
export declare class GoogleDataplexEntryAspectsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleDataplexEntryAspects[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexEntryAspectsOutputReference;
}
export interface GoogleDataplexEntryEntrySourceAncestors {
    /**
    * The name of the ancestor resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#name GoogleDataplexEntry#name}
    */
    readonly name?: string;
    /**
    * The type of the ancestor resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#type GoogleDataplexEntry#type}
    */
    readonly type?: string;
}
export declare function googleDataplexEntryEntrySourceAncestorsToTerraform(struct?: GoogleDataplexEntryEntrySourceAncestors | cdktf.IResolvable): any;
export declare function googleDataplexEntryEntrySourceAncestorsToHclTerraform(struct?: GoogleDataplexEntryEntrySourceAncestors | cdktf.IResolvable): any;
export declare class GoogleDataplexEntryEntrySourceAncestorsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexEntryEntrySourceAncestors | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDataplexEntryEntrySourceAncestors | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
}
export declare class GoogleDataplexEntryEntrySourceAncestorsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleDataplexEntryEntrySourceAncestors[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexEntryEntrySourceAncestorsOutputReference;
}
export interface GoogleDataplexEntryEntrySource {
    /**
    * The time when the resource was created in the source system.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#create_time GoogleDataplexEntry#create_time}
    */
    readonly createTime?: string;
    /**
    * A description of the data resource. Maximum length is 2,000 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#description GoogleDataplexEntry#description}
    */
    readonly description?: string;
    /**
    * A user-friendly display name. Maximum length is 500 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#display_name GoogleDataplexEntry#display_name}
    */
    readonly displayName?: string;
    /**
    * User-defined labels. The maximum size of keys and values is 128 characters each.
    * An object containing a list of "key": value pairs. Example: { "name": "wrench", "mass": "1.3kg", "count": "3" }.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#labels GoogleDataplexEntry#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The platform containing the source system. Maximum length is 64 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#platform GoogleDataplexEntry#platform}
    */
    readonly platform?: string;
    /**
    * The name of the resource in the source system. Maximum length is 4,000 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#resource GoogleDataplexEntry#resource}
    */
    readonly resource?: string;
    /**
    * The name of the source system. Maximum length is 64 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#system GoogleDataplexEntry#system}
    */
    readonly systemAttribute?: string;
    /**
    * The time when the resource was last updated in the source system.
    * If the entry exists in the system and its EntrySource has updateTime populated,
    * further updates to the EntrySource of the entry must provide incremental updates to its updateTime.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#update_time GoogleDataplexEntry#update_time}
    */
    readonly updateTime?: string;
    /**
    * ancestors block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#ancestors GoogleDataplexEntry#ancestors}
    */
    readonly ancestors?: GoogleDataplexEntryEntrySourceAncestors[] | cdktf.IResolvable;
}
export declare function googleDataplexEntryEntrySourceToTerraform(struct?: GoogleDataplexEntryEntrySourceOutputReference | GoogleDataplexEntryEntrySource): any;
export declare function googleDataplexEntryEntrySourceToHclTerraform(struct?: GoogleDataplexEntryEntrySourceOutputReference | GoogleDataplexEntryEntrySource): any;
export declare class GoogleDataplexEntryEntrySourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataplexEntryEntrySource | undefined;
    set internalValue(value: GoogleDataplexEntryEntrySource | undefined);
    private _createTime?;
    get createTime(): string;
    set createTime(value: string);
    resetCreateTime(): void;
    get createTimeInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    get location(): string;
    private _platform?;
    get platform(): string;
    set platform(value: string);
    resetPlatform(): void;
    get platformInput(): string | undefined;
    private _resource?;
    get resource(): string;
    set resource(value: string);
    resetResource(): void;
    get resourceInput(): string | undefined;
    private _system?;
    get systemAttribute(): string;
    set systemAttribute(value: string);
    resetSystemAttribute(): void;
    get systemAttributeInput(): string | undefined;
    private _updateTime?;
    get updateTime(): string;
    set updateTime(value: string);
    resetUpdateTime(): void;
    get updateTimeInput(): string | undefined;
    private _ancestors;
    get ancestors(): GoogleDataplexEntryEntrySourceAncestorsList;
    putAncestors(value: GoogleDataplexEntryEntrySourceAncestors[] | cdktf.IResolvable): void;
    resetAncestors(): void;
    get ancestorsInput(): cdktf.IResolvable | GoogleDataplexEntryEntrySourceAncestors[] | undefined;
}
export interface GoogleDataplexEntryTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#create GoogleDataplexEntry#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#delete GoogleDataplexEntry#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#update GoogleDataplexEntry#update}
    */
    readonly update?: string;
}
export declare function googleDataplexEntryTimeoutsToTerraform(struct?: GoogleDataplexEntryTimeouts | cdktf.IResolvable): any;
export declare function googleDataplexEntryTimeoutsToHclTerraform(struct?: GoogleDataplexEntryTimeouts | cdktf.IResolvable): any;
export declare class GoogleDataplexEntryTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataplexEntryTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDataplexEntryTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry google_dataplex_entry}
*/
export declare class GoogleDataplexEntry extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_dataplex_entry";
    /**
    * Generates CDKTF code for importing a GoogleDataplexEntry resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleDataplexEntry to import
    * @param importFromId The id of the existing GoogleDataplexEntry that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleDataplexEntry to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_dataplex_entry google_dataplex_entry} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleDataplexEntryConfig
    */
    constructor(scope: Construct, id: string, config: GoogleDataplexEntryConfig);
    get createTime(): string;
    private _entryGroupId?;
    get entryGroupId(): string;
    set entryGroupId(value: string);
    resetEntryGroupId(): void;
    get entryGroupIdInput(): string | undefined;
    private _entryId?;
    get entryId(): string;
    set entryId(value: string);
    resetEntryId(): void;
    get entryIdInput(): string | undefined;
    private _entryType?;
    get entryType(): string;
    set entryType(value: string);
    get entryTypeInput(): string | undefined;
    private _fullyQualifiedName?;
    get fullyQualifiedName(): string;
    set fullyQualifiedName(value: string);
    resetFullyQualifiedName(): void;
    get fullyQualifiedNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    get name(): string;
    private _parentEntry?;
    get parentEntry(): string;
    set parentEntry(value: string);
    resetParentEntry(): void;
    get parentEntryInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get updateTime(): string;
    private _aspects;
    get aspects(): GoogleDataplexEntryAspectsList;
    putAspects(value: GoogleDataplexEntryAspects[] | cdktf.IResolvable): void;
    resetAspects(): void;
    get aspectsInput(): cdktf.IResolvable | GoogleDataplexEntryAspects[] | undefined;
    private _entrySource;
    get entrySource(): GoogleDataplexEntryEntrySourceOutputReference;
    putEntrySource(value: GoogleDataplexEntryEntrySource): void;
    resetEntrySource(): void;
    get entrySourceInput(): GoogleDataplexEntryEntrySource | undefined;
    private _timeouts;
    get timeouts(): GoogleDataplexEntryTimeoutsOutputReference;
    putTimeouts(value: GoogleDataplexEntryTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleDataplexEntryTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
