/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleFirebaseAppHostingTrafficConfig extends cdktf.TerraformMetaArguments {
    /**
    * Id of the backend that this Traffic config applies to
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_firebase_app_hosting_traffic#backend GoogleFirebaseAppHostingTraffic#backend}
    */
    readonly backend: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_firebase_app_hosting_traffic#id GoogleFirebaseAppHostingTraffic#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The location the Backend that this Traffic config applies to
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_firebase_app_hosting_traffic#location GoogleFirebaseAppHostingTraffic#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_firebase_app_hosting_traffic#project GoogleFirebaseAppHostingTraffic#project}
    */
    readonly project?: string;
    /**
    * rollout_policy block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_firebase_app_hosting_traffic#rollout_policy GoogleFirebaseAppHostingTraffic#rollout_policy}
    */
    readonly rolloutPolicy?: GoogleFirebaseAppHostingTrafficRolloutPolicy;
    /**
    * target block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_firebase_app_hosting_traffic#target GoogleFirebaseAppHostingTraffic#target}
    */
    readonly target?: GoogleFirebaseAppHostingTrafficTarget;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_firebase_app_hosting_traffic#timeouts GoogleFirebaseAppHostingTraffic#timeouts}
    */
    readonly timeouts?: GoogleFirebaseAppHostingTrafficTimeouts;
}
export interface GoogleFirebaseAppHostingTrafficCurrentSplits {
}
export declare function googleFirebaseAppHostingTrafficCurrentSplitsToTerraform(struct?: GoogleFirebaseAppHostingTrafficCurrentSplits): any;
export declare function googleFirebaseAppHostingTrafficCurrentSplitsToHclTerraform(struct?: GoogleFirebaseAppHostingTrafficCurrentSplits): any;
export declare class GoogleFirebaseAppHostingTrafficCurrentSplitsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleFirebaseAppHostingTrafficCurrentSplits | undefined;
    set internalValue(value: GoogleFirebaseAppHostingTrafficCurrentSplits | undefined);
    get buildAttribute(): string;
    get percent(): number;
}
export declare class GoogleFirebaseAppHostingTrafficCurrentSplitsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleFirebaseAppHostingTrafficCurrentSplitsOutputReference;
}
export interface GoogleFirebaseAppHostingTrafficCurrent {
}
export declare function googleFirebaseAppHostingTrafficCurrentToTerraform(struct?: GoogleFirebaseAppHostingTrafficCurrent): any;
export declare function googleFirebaseAppHostingTrafficCurrentToHclTerraform(struct?: GoogleFirebaseAppHostingTrafficCurrent): any;
export declare class GoogleFirebaseAppHostingTrafficCurrentOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleFirebaseAppHostingTrafficCurrent | undefined;
    set internalValue(value: GoogleFirebaseAppHostingTrafficCurrent | undefined);
    private _splits;
    get splits(): GoogleFirebaseAppHostingTrafficCurrentSplitsList;
}
export declare class GoogleFirebaseAppHostingTrafficCurrentList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleFirebaseAppHostingTrafficCurrentOutputReference;
}
export interface GoogleFirebaseAppHostingTrafficRolloutPolicy {
    /**
    * Specifies a branch that triggers a new build to be started with this
    * policy. If not set, no automatic rollouts will happen.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_firebase_app_hosting_traffic#codebase_branch GoogleFirebaseAppHostingTraffic#codebase_branch}
    */
    readonly codebaseBranch?: string;
    /**
    * A flag that, if true, prevents rollouts from being created via this RolloutPolicy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_firebase_app_hosting_traffic#disabled GoogleFirebaseAppHostingTraffic#disabled}
    */
    readonly disabled?: boolean | cdktf.IResolvable;
}
export declare function googleFirebaseAppHostingTrafficRolloutPolicyToTerraform(struct?: GoogleFirebaseAppHostingTrafficRolloutPolicyOutputReference | GoogleFirebaseAppHostingTrafficRolloutPolicy): any;
export declare function googleFirebaseAppHostingTrafficRolloutPolicyToHclTerraform(struct?: GoogleFirebaseAppHostingTrafficRolloutPolicyOutputReference | GoogleFirebaseAppHostingTrafficRolloutPolicy): any;
export declare class GoogleFirebaseAppHostingTrafficRolloutPolicyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleFirebaseAppHostingTrafficRolloutPolicy | undefined;
    set internalValue(value: GoogleFirebaseAppHostingTrafficRolloutPolicy | undefined);
    private _codebaseBranch?;
    get codebaseBranch(): string;
    set codebaseBranch(value: string);
    resetCodebaseBranch(): void;
    get codebaseBranchInput(): string | undefined;
    private _disabled?;
    get disabled(): boolean | cdktf.IResolvable;
    set disabled(value: boolean | cdktf.IResolvable);
    resetDisabled(): void;
    get disabledInput(): boolean | cdktf.IResolvable | undefined;
    get disabledTime(): string;
}
export interface GoogleFirebaseAppHostingTrafficTargetSplits {
    /**
    * The build that traffic is being routed to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_firebase_app_hosting_traffic#build GoogleFirebaseAppHostingTraffic#build}
    */
    readonly buildAttribute: string;
    /**
    * The percentage of traffic to send to the build. Currently must be 100 or 0.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_firebase_app_hosting_traffic#percent GoogleFirebaseAppHostingTraffic#percent}
    */
    readonly percent: number;
}
export declare function googleFirebaseAppHostingTrafficTargetSplitsToTerraform(struct?: GoogleFirebaseAppHostingTrafficTargetSplits | cdktf.IResolvable): any;
export declare function googleFirebaseAppHostingTrafficTargetSplitsToHclTerraform(struct?: GoogleFirebaseAppHostingTrafficTargetSplits | cdktf.IResolvable): any;
export declare class GoogleFirebaseAppHostingTrafficTargetSplitsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleFirebaseAppHostingTrafficTargetSplits | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleFirebaseAppHostingTrafficTargetSplits | cdktf.IResolvable | undefined);
    private _build?;
    get buildAttribute(): string;
    set buildAttribute(value: string);
    get buildAttributeInput(): string | undefined;
    private _percent?;
    get percent(): number;
    set percent(value: number);
    get percentInput(): number | undefined;
}
export declare class GoogleFirebaseAppHostingTrafficTargetSplitsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleFirebaseAppHostingTrafficTargetSplits[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleFirebaseAppHostingTrafficTargetSplitsOutputReference;
}
export interface GoogleFirebaseAppHostingTrafficTarget {
    /**
    * splits block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_firebase_app_hosting_traffic#splits GoogleFirebaseAppHostingTraffic#splits}
    */
    readonly splits: GoogleFirebaseAppHostingTrafficTargetSplits[] | cdktf.IResolvable;
}
export declare function googleFirebaseAppHostingTrafficTargetToTerraform(struct?: GoogleFirebaseAppHostingTrafficTargetOutputReference | GoogleFirebaseAppHostingTrafficTarget): any;
export declare function googleFirebaseAppHostingTrafficTargetToHclTerraform(struct?: GoogleFirebaseAppHostingTrafficTargetOutputReference | GoogleFirebaseAppHostingTrafficTarget): any;
export declare class GoogleFirebaseAppHostingTrafficTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleFirebaseAppHostingTrafficTarget | undefined;
    set internalValue(value: GoogleFirebaseAppHostingTrafficTarget | undefined);
    private _splits;
    get splits(): GoogleFirebaseAppHostingTrafficTargetSplitsList;
    putSplits(value: GoogleFirebaseAppHostingTrafficTargetSplits[] | cdktf.IResolvable): void;
    get splitsInput(): cdktf.IResolvable | GoogleFirebaseAppHostingTrafficTargetSplits[] | undefined;
}
export interface GoogleFirebaseAppHostingTrafficTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_firebase_app_hosting_traffic#create GoogleFirebaseAppHostingTraffic#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_firebase_app_hosting_traffic#delete GoogleFirebaseAppHostingTraffic#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_firebase_app_hosting_traffic#update GoogleFirebaseAppHostingTraffic#update}
    */
    readonly update?: string;
}
export declare function googleFirebaseAppHostingTrafficTimeoutsToTerraform(struct?: GoogleFirebaseAppHostingTrafficTimeouts | cdktf.IResolvable): any;
export declare function googleFirebaseAppHostingTrafficTimeoutsToHclTerraform(struct?: GoogleFirebaseAppHostingTrafficTimeouts | cdktf.IResolvable): any;
export declare class GoogleFirebaseAppHostingTrafficTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleFirebaseAppHostingTrafficTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleFirebaseAppHostingTrafficTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_firebase_app_hosting_traffic google_firebase_app_hosting_traffic}
*/
export declare class GoogleFirebaseAppHostingTraffic extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_firebase_app_hosting_traffic";
    /**
    * Generates CDKTF code for importing a GoogleFirebaseAppHostingTraffic resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleFirebaseAppHostingTraffic to import
    * @param importFromId The id of the existing GoogleFirebaseAppHostingTraffic that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_firebase_app_hosting_traffic#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleFirebaseAppHostingTraffic to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_firebase_app_hosting_traffic google_firebase_app_hosting_traffic} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleFirebaseAppHostingTrafficConfig
    */
    constructor(scope: Construct, id: string, config: GoogleFirebaseAppHostingTrafficConfig);
    private _backend?;
    get backend(): string;
    set backend(value: string);
    get backendInput(): string | undefined;
    get createTime(): string;
    private _current;
    get current(): GoogleFirebaseAppHostingTrafficCurrentList;
    get deleteTime(): string;
    get etag(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get uid(): string;
    get updateTime(): string;
    private _rolloutPolicy;
    get rolloutPolicy(): GoogleFirebaseAppHostingTrafficRolloutPolicyOutputReference;
    putRolloutPolicy(value: GoogleFirebaseAppHostingTrafficRolloutPolicy): void;
    resetRolloutPolicy(): void;
    get rolloutPolicyInput(): GoogleFirebaseAppHostingTrafficRolloutPolicy | undefined;
    private _target;
    get target(): GoogleFirebaseAppHostingTrafficTargetOutputReference;
    putTarget(value: GoogleFirebaseAppHostingTrafficTarget): void;
    resetTarget(): void;
    get targetInput(): GoogleFirebaseAppHostingTrafficTarget | undefined;
    private _timeouts;
    get timeouts(): GoogleFirebaseAppHostingTrafficTimeoutsOutputReference;
    putTimeouts(value: GoogleFirebaseAppHostingTrafficTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleFirebaseAppHostingTrafficTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
