/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleIamWorkforcePoolProviderKeyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workforce_pool_provider_key#id GoogleIamWorkforcePoolProviderKey#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The ID to use for the key, which becomes the final component of the resource name. This value must be 4-32 characters, and may contain the characters [a-z0-9-].
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workforce_pool_provider_key#key_id GoogleIamWorkforcePoolProviderKey#key_id}
    */
    readonly keyId: string;
    /**
    * The location for the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workforce_pool_provider_key#location GoogleIamWorkforcePoolProviderKey#location}
    */
    readonly location: string;
    /**
    * The ID of the provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workforce_pool_provider_key#provider_id GoogleIamWorkforcePoolProviderKey#provider_id}
    */
    readonly providerId: string;
    /**
    * The purpose of the key. Possible values: ["ENCRYPTION"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workforce_pool_provider_key#use GoogleIamWorkforcePoolProviderKey#use}
    */
    readonly use: string;
    /**
    * The ID of the workforce pool.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workforce_pool_provider_key#workforce_pool_id GoogleIamWorkforcePoolProviderKey#workforce_pool_id}
    */
    readonly workforcePoolId: string;
    /**
    * key_data block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workforce_pool_provider_key#key_data GoogleIamWorkforcePoolProviderKey#key_data}
    */
    readonly keyData: GoogleIamWorkforcePoolProviderKeyKeyData;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workforce_pool_provider_key#timeouts GoogleIamWorkforcePoolProviderKey#timeouts}
    */
    readonly timeouts?: GoogleIamWorkforcePoolProviderKeyTimeouts;
}
export interface GoogleIamWorkforcePoolProviderKeyKeyData {
    /**
    * The specifications for the key. Possible values: ["RSA_2048", "RSA_3072", "RSA_4096"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workforce_pool_provider_key#key_spec GoogleIamWorkforcePoolProviderKey#key_spec}
    */
    readonly keySpec: string;
}
export declare function googleIamWorkforcePoolProviderKeyKeyDataToTerraform(struct?: GoogleIamWorkforcePoolProviderKeyKeyDataOutputReference | GoogleIamWorkforcePoolProviderKeyKeyData): any;
export declare function googleIamWorkforcePoolProviderKeyKeyDataToHclTerraform(struct?: GoogleIamWorkforcePoolProviderKeyKeyDataOutputReference | GoogleIamWorkforcePoolProviderKeyKeyData): any;
export declare class GoogleIamWorkforcePoolProviderKeyKeyDataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIamWorkforcePoolProviderKeyKeyData | undefined;
    set internalValue(value: GoogleIamWorkforcePoolProviderKeyKeyData | undefined);
    get format(): string;
    get key(): string;
    private _keySpec?;
    get keySpec(): string;
    set keySpec(value: string);
    get keySpecInput(): string | undefined;
    get notAfterTime(): string;
    get notBeforeTime(): string;
}
export interface GoogleIamWorkforcePoolProviderKeyTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workforce_pool_provider_key#create GoogleIamWorkforcePoolProviderKey#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workforce_pool_provider_key#delete GoogleIamWorkforcePoolProviderKey#delete}
    */
    readonly delete?: string;
}
export declare function googleIamWorkforcePoolProviderKeyTimeoutsToTerraform(struct?: GoogleIamWorkforcePoolProviderKeyTimeouts | cdktf.IResolvable): any;
export declare function googleIamWorkforcePoolProviderKeyTimeoutsToHclTerraform(struct?: GoogleIamWorkforcePoolProviderKeyTimeouts | cdktf.IResolvable): any;
export declare class GoogleIamWorkforcePoolProviderKeyTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIamWorkforcePoolProviderKeyTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleIamWorkforcePoolProviderKeyTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workforce_pool_provider_key google_iam_workforce_pool_provider_key}
*/
export declare class GoogleIamWorkforcePoolProviderKey extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_iam_workforce_pool_provider_key";
    /**
    * Generates CDKTF code for importing a GoogleIamWorkforcePoolProviderKey resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleIamWorkforcePoolProviderKey to import
    * @param importFromId The id of the existing GoogleIamWorkforcePoolProviderKey that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workforce_pool_provider_key#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleIamWorkforcePoolProviderKey to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workforce_pool_provider_key google_iam_workforce_pool_provider_key} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleIamWorkforcePoolProviderKeyConfig
    */
    constructor(scope: Construct, id: string, config: GoogleIamWorkforcePoolProviderKeyConfig);
    get expireTime(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _keyId?;
    get keyId(): string;
    set keyId(value: string);
    get keyIdInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _providerId?;
    get providerId(): string;
    set providerId(value: string);
    get providerIdInput(): string | undefined;
    get state(): string;
    private _use?;
    get use(): string;
    set use(value: string);
    get useInput(): string | undefined;
    private _workforcePoolId?;
    get workforcePoolId(): string;
    set workforcePoolId(value: string);
    get workforcePoolIdInput(): string | undefined;
    private _keyData;
    get keyData(): GoogleIamWorkforcePoolProviderKeyKeyDataOutputReference;
    putKeyData(value: GoogleIamWorkforcePoolProviderKeyKeyData): void;
    get keyDataInput(): GoogleIamWorkforcePoolProviderKeyKeyData | undefined;
    private _timeouts;
    get timeouts(): GoogleIamWorkforcePoolProviderKeyTimeoutsOutputReference;
    putTimeouts(value: GoogleIamWorkforcePoolProviderKeyTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleIamWorkforcePoolProviderKeyTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
