/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleIamWorkloadIdentityPoolManagedIdentityConfig extends cdktf.TerraformMetaArguments {
    /**
    * A description of the managed identity. Cannot exceed 256 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_managed_identity#description GoogleIamWorkloadIdentityPoolManagedIdentity#description}
    */
    readonly description?: string;
    /**
    * Whether the managed identity is disabled. If disabled, credentials may no longer be issued for
    * the identity, however existing credentials will still be accepted until they expire.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_managed_identity#disabled GoogleIamWorkloadIdentityPoolManagedIdentity#disabled}
    */
    readonly disabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_managed_identity#id GoogleIamWorkloadIdentityPoolManagedIdentity#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_managed_identity#project GoogleIamWorkloadIdentityPoolManagedIdentity#project}
    */
    readonly project?: string;
    /**
    * The ID to use for the pool, which becomes the final component of the resource name. This
    * value should be 4-32 characters, and may contain the characters [a-z0-9-]. The prefix
    * 'gcp-' is reserved for use by Google, and may not be specified.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_managed_identity#workload_identity_pool_id GoogleIamWorkloadIdentityPoolManagedIdentity#workload_identity_pool_id}
    */
    readonly workloadIdentityPoolId: string;
    /**
    * The ID to use for the managed identity. This value must:
    * * contain at most 63 characters
    * * contain only lowercase alphanumeric characters or '-'
    * * start with an alphanumeric character
    * * end with an alphanumeric character
    *
    *
    * The prefix 'gcp-' will be reserved for future uses.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_managed_identity#workload_identity_pool_managed_identity_id GoogleIamWorkloadIdentityPoolManagedIdentity#workload_identity_pool_managed_identity_id}
    */
    readonly workloadIdentityPoolManagedIdentityId: string;
    /**
    * The ID to use for the namespace. This value must:
    * * contain at most 63 characters
    * * contain only lowercase alphanumeric characters or '-'
    * * start with an alphanumeric character
    * * end with an alphanumeric character
    *
    *
    * The prefix 'gcp-' will be reserved for future uses.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_managed_identity#workload_identity_pool_namespace_id GoogleIamWorkloadIdentityPoolManagedIdentity#workload_identity_pool_namespace_id}
    */
    readonly workloadIdentityPoolNamespaceId: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_managed_identity#timeouts GoogleIamWorkloadIdentityPoolManagedIdentity#timeouts}
    */
    readonly timeouts?: GoogleIamWorkloadIdentityPoolManagedIdentityTimeouts;
}
export interface GoogleIamWorkloadIdentityPoolManagedIdentityTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_managed_identity#create GoogleIamWorkloadIdentityPoolManagedIdentity#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_managed_identity#delete GoogleIamWorkloadIdentityPoolManagedIdentity#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_managed_identity#update GoogleIamWorkloadIdentityPoolManagedIdentity#update}
    */
    readonly update?: string;
}
export declare function googleIamWorkloadIdentityPoolManagedIdentityTimeoutsToTerraform(struct?: GoogleIamWorkloadIdentityPoolManagedIdentityTimeouts | cdktf.IResolvable): any;
export declare function googleIamWorkloadIdentityPoolManagedIdentityTimeoutsToHclTerraform(struct?: GoogleIamWorkloadIdentityPoolManagedIdentityTimeouts | cdktf.IResolvable): any;
export declare class GoogleIamWorkloadIdentityPoolManagedIdentityTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIamWorkloadIdentityPoolManagedIdentityTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleIamWorkloadIdentityPoolManagedIdentityTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_managed_identity google_iam_workload_identity_pool_managed_identity}
*/
export declare class GoogleIamWorkloadIdentityPoolManagedIdentity extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_iam_workload_identity_pool_managed_identity";
    /**
    * Generates CDKTF code for importing a GoogleIamWorkloadIdentityPoolManagedIdentity resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleIamWorkloadIdentityPoolManagedIdentity to import
    * @param importFromId The id of the existing GoogleIamWorkloadIdentityPoolManagedIdentity that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_managed_identity#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleIamWorkloadIdentityPoolManagedIdentity to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_managed_identity google_iam_workload_identity_pool_managed_identity} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleIamWorkloadIdentityPoolManagedIdentityConfig
    */
    constructor(scope: Construct, id: string, config: GoogleIamWorkloadIdentityPoolManagedIdentityConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _disabled?;
    get disabled(): boolean | cdktf.IResolvable;
    set disabled(value: boolean | cdktf.IResolvable);
    resetDisabled(): void;
    get disabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get state(): string;
    private _workloadIdentityPoolId?;
    get workloadIdentityPoolId(): string;
    set workloadIdentityPoolId(value: string);
    get workloadIdentityPoolIdInput(): string | undefined;
    private _workloadIdentityPoolManagedIdentityId?;
    get workloadIdentityPoolManagedIdentityId(): string;
    set workloadIdentityPoolManagedIdentityId(value: string);
    get workloadIdentityPoolManagedIdentityIdInput(): string | undefined;
    private _workloadIdentityPoolNamespaceId?;
    get workloadIdentityPoolNamespaceId(): string;
    set workloadIdentityPoolNamespaceId(value: string);
    get workloadIdentityPoolNamespaceIdInput(): string | undefined;
    private _timeouts;
    get timeouts(): GoogleIamWorkloadIdentityPoolManagedIdentityTimeoutsOutputReference;
    putTimeouts(value: GoogleIamWorkloadIdentityPoolManagedIdentityTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleIamWorkloadIdentityPoolManagedIdentityTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
