/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleIamWorkloadIdentityPoolNamespaceConfig extends cdktf.TerraformMetaArguments {
    /**
    * A description of the namespace. Cannot exceed 256 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_namespace#description GoogleIamWorkloadIdentityPoolNamespace#description}
    */
    readonly description?: string;
    /**
    * Whether the namespace is disabled. If disabled, credentials may no longer be issued for
    * identities within this namespace, however existing credentials will still be accepted until
    * they expire.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_namespace#disabled GoogleIamWorkloadIdentityPoolNamespace#disabled}
    */
    readonly disabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_namespace#id GoogleIamWorkloadIdentityPoolNamespace#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_namespace#project GoogleIamWorkloadIdentityPoolNamespace#project}
    */
    readonly project?: string;
    /**
    * The ID to use for the pool, which becomes the final component of the resource name. This
    * value should be 4-32 characters, and may contain the characters [a-z0-9-]. The prefix
    * 'gcp-' is reserved for use by Google, and may not be specified.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_namespace#workload_identity_pool_id GoogleIamWorkloadIdentityPoolNamespace#workload_identity_pool_id}
    */
    readonly workloadIdentityPoolId: string;
    /**
    * The ID to use for the namespace. This value must:
    * * contain at most 63 characters
    * * contain only lowercase alphanumeric characters or '-'
    * * start with an alphanumeric character
    * * end with an alphanumeric character
    *
    *
    * The prefix 'gcp-' will be reserved for future uses.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_namespace#workload_identity_pool_namespace_id GoogleIamWorkloadIdentityPoolNamespace#workload_identity_pool_namespace_id}
    */
    readonly workloadIdentityPoolNamespaceId: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_namespace#timeouts GoogleIamWorkloadIdentityPoolNamespace#timeouts}
    */
    readonly timeouts?: GoogleIamWorkloadIdentityPoolNamespaceTimeouts;
}
export interface GoogleIamWorkloadIdentityPoolNamespaceOwnerService {
}
export declare function googleIamWorkloadIdentityPoolNamespaceOwnerServiceToTerraform(struct?: GoogleIamWorkloadIdentityPoolNamespaceOwnerService): any;
export declare function googleIamWorkloadIdentityPoolNamespaceOwnerServiceToHclTerraform(struct?: GoogleIamWorkloadIdentityPoolNamespaceOwnerService): any;
export declare class GoogleIamWorkloadIdentityPoolNamespaceOwnerServiceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleIamWorkloadIdentityPoolNamespaceOwnerService | undefined;
    set internalValue(value: GoogleIamWorkloadIdentityPoolNamespaceOwnerService | undefined);
    get principalSubject(): string;
}
export declare class GoogleIamWorkloadIdentityPoolNamespaceOwnerServiceList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleIamWorkloadIdentityPoolNamespaceOwnerServiceOutputReference;
}
export interface GoogleIamWorkloadIdentityPoolNamespaceTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_namespace#create GoogleIamWorkloadIdentityPoolNamespace#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_namespace#delete GoogleIamWorkloadIdentityPoolNamespace#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_namespace#update GoogleIamWorkloadIdentityPoolNamespace#update}
    */
    readonly update?: string;
}
export declare function googleIamWorkloadIdentityPoolNamespaceTimeoutsToTerraform(struct?: GoogleIamWorkloadIdentityPoolNamespaceTimeouts | cdktf.IResolvable): any;
export declare function googleIamWorkloadIdentityPoolNamespaceTimeoutsToHclTerraform(struct?: GoogleIamWorkloadIdentityPoolNamespaceTimeouts | cdktf.IResolvable): any;
export declare class GoogleIamWorkloadIdentityPoolNamespaceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIamWorkloadIdentityPoolNamespaceTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleIamWorkloadIdentityPoolNamespaceTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_namespace google_iam_workload_identity_pool_namespace}
*/
export declare class GoogleIamWorkloadIdentityPoolNamespace extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_iam_workload_identity_pool_namespace";
    /**
    * Generates CDKTF code for importing a GoogleIamWorkloadIdentityPoolNamespace resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleIamWorkloadIdentityPoolNamespace to import
    * @param importFromId The id of the existing GoogleIamWorkloadIdentityPoolNamespace that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_namespace#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleIamWorkloadIdentityPoolNamespace to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_iam_workload_identity_pool_namespace google_iam_workload_identity_pool_namespace} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleIamWorkloadIdentityPoolNamespaceConfig
    */
    constructor(scope: Construct, id: string, config: GoogleIamWorkloadIdentityPoolNamespaceConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _disabled?;
    get disabled(): boolean | cdktf.IResolvable;
    set disabled(value: boolean | cdktf.IResolvable);
    resetDisabled(): void;
    get disabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _ownerService;
    get ownerService(): GoogleIamWorkloadIdentityPoolNamespaceOwnerServiceList;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get state(): string;
    private _workloadIdentityPoolId?;
    get workloadIdentityPoolId(): string;
    set workloadIdentityPoolId(value: string);
    get workloadIdentityPoolIdInput(): string | undefined;
    private _workloadIdentityPoolNamespaceId?;
    get workloadIdentityPoolNamespaceId(): string;
    set workloadIdentityPoolNamespaceId(value: string);
    get workloadIdentityPoolNamespaceIdInput(): string | undefined;
    private _timeouts;
    get timeouts(): GoogleIamWorkloadIdentityPoolNamespaceTimeoutsOutputReference;
    putTimeouts(value: GoogleIamWorkloadIdentityPoolNamespaceTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleIamWorkloadIdentityPoolNamespaceTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
