/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleNetappBackupVaultConfig extends cdktf.TerraformMetaArguments {
    /**
    * Region in which backup is stored.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault#backup_region GoogleNetappBackupVault#backup_region}
    */
    readonly backupRegion?: string;
    /**
    * Type of the backup vault to be created. Default is IN_REGION. Possible values: ["BACKUP_VAULT_TYPE_UNSPECIFIED", "IN_REGION", "CROSS_REGION"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault#backup_vault_type GoogleNetappBackupVault#backup_vault_type}
    */
    readonly backupVaultType?: string;
    /**
    * An optional description of this resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault#description GoogleNetappBackupVault#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault#id GoogleNetappBackupVault#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Labels as key value pairs. Example: '{ "owner": "Bob", "department": "finance", "purpose": "testing" }'.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault#labels GoogleNetappBackupVault#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Location (region) of the backup vault.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault#location GoogleNetappBackupVault#location}
    */
    readonly location: string;
    /**
    * The resource name of the backup vault. Needs to be unique per location.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault#name GoogleNetappBackupVault#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault#project GoogleNetappBackupVault#project}
    */
    readonly project?: string;
    /**
    * backup_retention_policy block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault#backup_retention_policy GoogleNetappBackupVault#backup_retention_policy}
    */
    readonly backupRetentionPolicy?: GoogleNetappBackupVaultBackupRetentionPolicy;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault#timeouts GoogleNetappBackupVault#timeouts}
    */
    readonly timeouts?: GoogleNetappBackupVaultTimeouts;
}
export interface GoogleNetappBackupVaultBackupRetentionPolicy {
    /**
    * Minimum retention duration in days for backups in the backup vault.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault#backup_minimum_enforced_retention_days GoogleNetappBackupVault#backup_minimum_enforced_retention_days}
    */
    readonly backupMinimumEnforcedRetentionDays: number;
    /**
    * Indicates if the daily backups are immutable. At least one of daily_backup_immutable, weekly_backup_immutable, monthly_backup_immutable and manual_backup_immutable must be true.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault#daily_backup_immutable GoogleNetappBackupVault#daily_backup_immutable}
    */
    readonly dailyBackupImmutable?: boolean | cdktf.IResolvable;
    /**
    * Indicates if the manual backups are immutable. At least one of daily_backup_immutable, weekly_backup_immutable, monthly_backup_immutable and manual_backup_immutable must be true.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault#manual_backup_immutable GoogleNetappBackupVault#manual_backup_immutable}
    */
    readonly manualBackupImmutable?: boolean | cdktf.IResolvable;
    /**
    * Indicates if the monthly backups are immutable. At least one of daily_backup_immutable, weekly_backup_immutable, monthly_backup_immutable and manual_backup_immutable must be true.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault#monthly_backup_immutable GoogleNetappBackupVault#monthly_backup_immutable}
    */
    readonly monthlyBackupImmutable?: boolean | cdktf.IResolvable;
    /**
    * Indicates if the weekly backups are immutable. At least one of daily_backup_immutable, weekly_backup_immutable, monthly_backup_immutable and manual_backup_immutable must be true.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault#weekly_backup_immutable GoogleNetappBackupVault#weekly_backup_immutable}
    */
    readonly weeklyBackupImmutable?: boolean | cdktf.IResolvable;
}
export declare function googleNetappBackupVaultBackupRetentionPolicyToTerraform(struct?: GoogleNetappBackupVaultBackupRetentionPolicyOutputReference | GoogleNetappBackupVaultBackupRetentionPolicy): any;
export declare function googleNetappBackupVaultBackupRetentionPolicyToHclTerraform(struct?: GoogleNetappBackupVaultBackupRetentionPolicyOutputReference | GoogleNetappBackupVaultBackupRetentionPolicy): any;
export declare class GoogleNetappBackupVaultBackupRetentionPolicyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetappBackupVaultBackupRetentionPolicy | undefined;
    set internalValue(value: GoogleNetappBackupVaultBackupRetentionPolicy | undefined);
    private _backupMinimumEnforcedRetentionDays?;
    get backupMinimumEnforcedRetentionDays(): number;
    set backupMinimumEnforcedRetentionDays(value: number);
    get backupMinimumEnforcedRetentionDaysInput(): number | undefined;
    private _dailyBackupImmutable?;
    get dailyBackupImmutable(): boolean | cdktf.IResolvable;
    set dailyBackupImmutable(value: boolean | cdktf.IResolvable);
    resetDailyBackupImmutable(): void;
    get dailyBackupImmutableInput(): boolean | cdktf.IResolvable | undefined;
    private _manualBackupImmutable?;
    get manualBackupImmutable(): boolean | cdktf.IResolvable;
    set manualBackupImmutable(value: boolean | cdktf.IResolvable);
    resetManualBackupImmutable(): void;
    get manualBackupImmutableInput(): boolean | cdktf.IResolvable | undefined;
    private _monthlyBackupImmutable?;
    get monthlyBackupImmutable(): boolean | cdktf.IResolvable;
    set monthlyBackupImmutable(value: boolean | cdktf.IResolvable);
    resetMonthlyBackupImmutable(): void;
    get monthlyBackupImmutableInput(): boolean | cdktf.IResolvable | undefined;
    private _weeklyBackupImmutable?;
    get weeklyBackupImmutable(): boolean | cdktf.IResolvable;
    set weeklyBackupImmutable(value: boolean | cdktf.IResolvable);
    resetWeeklyBackupImmutable(): void;
    get weeklyBackupImmutableInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleNetappBackupVaultTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault#create GoogleNetappBackupVault#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault#delete GoogleNetappBackupVault#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault#update GoogleNetappBackupVault#update}
    */
    readonly update?: string;
}
export declare function googleNetappBackupVaultTimeoutsToTerraform(struct?: GoogleNetappBackupVaultTimeouts | cdktf.IResolvable): any;
export declare function googleNetappBackupVaultTimeoutsToHclTerraform(struct?: GoogleNetappBackupVaultTimeouts | cdktf.IResolvable): any;
export declare class GoogleNetappBackupVaultTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetappBackupVaultTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleNetappBackupVaultTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault google_netapp_backup_vault}
*/
export declare class GoogleNetappBackupVault extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_netapp_backup_vault";
    /**
    * Generates CDKTF code for importing a GoogleNetappBackupVault resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleNetappBackupVault to import
    * @param importFromId The id of the existing GoogleNetappBackupVault that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleNetappBackupVault to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.38.0/docs/resources/google_netapp_backup_vault google_netapp_backup_vault} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleNetappBackupVaultConfig
    */
    constructor(scope: Construct, id: string, config: GoogleNetappBackupVaultConfig);
    private _backupRegion?;
    get backupRegion(): string;
    set backupRegion(value: string);
    resetBackupRegion(): void;
    get backupRegionInput(): string | undefined;
    private _backupVaultType?;
    get backupVaultType(): string;
    set backupVaultType(value: string);
    resetBackupVaultType(): void;
    get backupVaultTypeInput(): string | undefined;
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    get destinationBackupVault(): string;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get sourceBackupVault(): string;
    get sourceRegion(): string;
    get state(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    private _backupRetentionPolicy;
    get backupRetentionPolicy(): GoogleNetappBackupVaultBackupRetentionPolicyOutputReference;
    putBackupRetentionPolicy(value: GoogleNetappBackupVaultBackupRetentionPolicy): void;
    resetBackupRetentionPolicy(): void;
    get backupRetentionPolicyInput(): GoogleNetappBackupVaultBackupRetentionPolicy | undefined;
    private _timeouts;
    get timeouts(): GoogleNetappBackupVaultTimeoutsOutputReference;
    putTimeouts(value: GoogleNetappBackupVaultTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleNetappBackupVaultTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
